@@ -13,7 +13,6 @@
 #    under the License.
 
 import copy
-import itertools
 
 from oslo_log import log as logging
 from pecan import request
@@ -185,27 +184,36 @@ class PaginationHelper(object):
         if not getattr(model, "_tags", None):
             return query
 
+        tag_alias = aliased(base_models.Tags)
+
         if 'tags' in params:
             tags = params.pop('tags')
+            if not isinstance(tags, list):
+                tags = [tags]
+            first_tag = tags.pop(0)
+            query = query.join(model._tags)
+            query = query.filter(base_models.Tags.tag == first_tag)
 
             for tag in tags:
-                # This requires a multi-join to the tags table,
-                # so me must use aliases for each one.
-                tag_alias = aliased(base_models.Tags)
                 query = query.join(tag_alias, model._tags)
                 query = query.filter(tag_alias.tag == tag)
 
         if 'tags-any' in params:
             tags = params.pop('tags-any')
-            tag_alias = aliased(base_models.Tags)
+            if not isinstance(tags, list):
+                tags = [tags]
             query = query.join(tag_alias, model._tags)
             query = query.filter(tag_alias.tag.in_(tags))
 
         if 'not-tags' in params:
             tags = params.pop('not-tags')
-            subq = query.session.query(model.id)
+            if not isinstance(tags, list):
+                tags = [tags]
+            first_tag = tags.pop(0)
+            subq = query.session.query(base_models.Tags.resource_id)
+            subq = subq.join(model._tags)
+            subq = subq.filter(base_models.Tags.tag == first_tag)
             for tag in tags:
-                tag_alias = aliased(base_models.Tags)
                 subq = subq.join(tag_alias, model._tags)
                 subq = subq.filter(tag_alias.tag == tag)
 
@@ -213,19 +221,13 @@ class PaginationHelper(object):
 
         if 'not-tags-any' in params:
             tags = params.pop('not-tags-any')
+            if not isinstance(tags, list):
+                tags = [tags]
             query = query.filter(
                 ~model._tags.any(base_models.Tags.tag.in_(tags)))
 
         return query
 
-    @staticmethod
-    def _prepare_tags_list(param):
-        """Split comma seperated tags and return a flat list of tags."""
-        if not isinstance(param, list):
-            param = [param]
-        return list(itertools.chain.from_iterable(
-            tag.split(',') for tag in param))
-
     def apply(self, query, model, enforce_valid_params=True):
         """Returns a query with sorting / pagination criteria added.
 
@@ -268,22 +270,8 @@ class PaginationHelper(object):
                 filter_params['load_balancer_id'] = filter_params.pop(
                     'loadbalancer_id')
 
-            # Pop the 'tags' related parameters off before handling the
-            # other filters. Then apply the 'tags' filters after the
-            # other filters have been applied.
-            tag_params = {}
-            if 'tags' in filter_params:
-                tag_params['tags'] = self._prepare_tags_list(
-                    filter_params.pop('tags'))
-            if 'tags-any' in filter_params:
-                tag_params['tags-any'] = self._prepare_tags_list(
-                    filter_params.pop('tags-any'))
-            if 'not-tags' in filter_params:
-                tag_params['not-tags'] = self._prepare_tags_list(
-                    filter_params.pop('not-tags'))
-            if 'not-tags-any' in filter_params:
-                tag_params['not-tags-any'] = self._prepare_tags_list(
-                    filter_params.pop('not-tags-any'))
+            # Apply tags filtering for the models which support tags.
+            query = self._apply_tags_filtering(filter_params, model, query)
 
             # Drop invalid arguments
             self.filters = {k: v for (k, v) in filter_params.items()
@@ -299,9 +287,6 @@ class PaginationHelper(object):
                 query = query.filter(model.load_balancer.has(
                     project_id=secondary_query_filter))
 
-            # Apply tags filtering for the models which support tags.
-            query = self._apply_tags_filtering(tag_params, model, query)
-
         # Add sorting
         if CONF.api_settings.allow_sorting:
             # Add default sort keys (if they are OK for the model)
@@ -311,26 +296,13 @@ class PaginationHelper(object):
                     self.sort_keys.append((key, self.sort_dir))
 
             for current_sort_key, current_sort_dir in self.sort_keys:
-                # Translate sort_key from API standard to data model's name
-                current_sort_key = (
-                    model.__v2_wsme__.translate_key_to_data_model(
-                        current_sort_key))
                 sort_dir_func = {
                     constants.ASC: sqlalchemy.asc,
                     constants.DESC: sqlalchemy.desc,
                 }[current_sort_dir]
 
                 try:
-                    # The translated object may be a nested parameter
-                    # such as vip.ip_address, so handle that case by
-                    # joining with the nested table.
-                    if '.' in current_sort_key:
-                        parent, child = current_sort_key.split('.')
-                        parent_obj = getattr(model, parent)
-                        query = query.join(parent_obj)
-                        sort_key_attr = child
-                    else:
-                        sort_key_attr = getattr(model, current_sort_key)
+                    sort_key_attr = getattr(model, current_sort_key)
                 except AttributeError:
                     raise exceptions.InvalidSortKey(key=current_sort_key)
                 query = query.order_by(sort_dir_func(sort_key_attr))
@@ -358,7 +330,7 @@ class PaginationHelper(object):
                         default = PaginationHelper._get_default_column_value(
                             model_attr.property.columns[0].type)
                         attr = sa_sql.expression.case(
-                            [(model_attr != None,  # noqa: E711
+                            [(model_attr != None,  # noqa: E711 # pylint: disable=singleton-comparison
                               model_attr), ], else_=default)
                         crit_attrs.append((attr == marker_values[j]))
 
@@ -366,7 +338,7 @@ class PaginationHelper(object):
                     default = PaginationHelper._get_default_column_value(
                         model_attr.property.columns[0].type)
                     attr = sa_sql.expression.case(
-                        [(model_attr != None,  # noqa: E711
+                        [(model_attr != None,  # noqa: E711 # pylint: disable=singleton-comparison
                           model_attr), ], else_=default)
                     this_sort_dir = self.sort_keys[i][1]
                     if this_sort_dir == constants.DESC:
