@@ -16,18 +16,19 @@ import copy
 
 import six
 
+from octavia_lib.api.drivers import data_models as driver_dm
 from octavia_lib.api.drivers import exceptions as lib_exceptions
 from oslo_config import cfg
 from oslo_context import context as oslo_context
 from oslo_log import log as logging
-from oslo_utils import excutils
 from stevedore import driver as stevedore_driver
 
-from octavia.api.drivers import data_models as driver_dm
 from octavia.api.drivers import exceptions as driver_exceptions
 from octavia.common import data_models
 from octavia.common import exceptions
 from octavia.common.tls_utils import cert_parser
+from octavia.db import api as db_api
+from octavia.db import repositories
 from octavia.i18n import _
 
 LOG = logging.getLogger(__name__)
@@ -106,13 +107,25 @@ def _base_to_provider_dict(current_dict, include_project_id=False):
         del new_dict['flavor_id']
     if 'topology' in new_dict:
         del new_dict['topology']
+    if 'vrrp_group' in new_dict:
+        del new_dict['vrrp_group']
+    if 'amphorae' in new_dict:
+        del new_dict['amphorae']
+    if 'vip' in new_dict:
+        del new_dict['vip']
+    if 'listeners' in new_dict:
+        del new_dict['listeners']
+    if 'pools' in new_dict:
+        del new_dict['pools']
+    if 'server_group_id' in new_dict:
+        del new_dict['server_group_id']
     return new_dict
 
 
 # Note: The provider dict returned from this method will have provider
 #       data model objects in it.
-def lb_dict_to_provider_dict(lb_dict, vip=None, db_pools=None,
-                             db_listeners=None, for_delete=False):
+def lb_dict_to_provider_dict(lb_dict, vip=None,
+                             db_pools=None, db_listeners=None):
     new_lb_dict = _base_to_provider_dict(lb_dict, include_project_id=True)
     new_lb_dict['loadbalancer_id'] = new_lb_dict.pop('id')
     if vip:
@@ -121,23 +134,24 @@ def lb_dict_to_provider_dict(lb_dict, vip=None, db_pools=None,
         new_lb_dict['vip_port_id'] = vip.port_id
         new_lb_dict['vip_subnet_id'] = vip.subnet_id
         new_lb_dict['vip_qos_policy_id'] = vip.qos_policy_id
-
+    if 'flavor_id' in lb_dict and lb_dict['flavor_id']:
+        flavor_repo = repositories.FlavorRepository()
+        new_lb_dict['flavor'] = flavor_repo.get_flavor_metadata_dict(
+            db_api.get_session(), lb_dict['flavor_id'])
     if db_pools:
-        new_lb_dict['pools'] = db_pools_to_provider_pools(
-            db_pools, for_delete=for_delete)
+        new_lb_dict['pools'] = db_pools_to_provider_pools(db_pools)
     if db_listeners:
         new_lb_dict['listeners'] = db_listeners_to_provider_listeners(
-            db_listeners, for_delete=for_delete)
+            db_listeners)
     return new_lb_dict
 
 
-def db_loadbalancer_to_provider_loadbalancer(db_loadbalancer,
-                                             for_delete=False):
+def db_loadbalancer_to_provider_loadbalancer(db_loadbalancer):
     new_loadbalancer_dict = lb_dict_to_provider_dict(
         db_loadbalancer.to_dict(recurse=True),
         vip=db_loadbalancer.vip,
         db_pools=db_loadbalancer.pools,
-        db_listeners=db_loadbalancer.listeners, for_delete=for_delete)
+        db_listeners=db_loadbalancer.listeners)
     for unsupported_field in ['server_group_id', 'amphorae',
                               'vrrp_group', 'topology', 'vip']:
         if unsupported_field in new_loadbalancer_dict:
@@ -147,22 +161,20 @@ def db_loadbalancer_to_provider_loadbalancer(db_loadbalancer,
     return provider_loadbalancer
 
 
-def db_listeners_to_provider_listeners(db_listeners, for_delete=False):
+def db_listeners_to_provider_listeners(db_listeners):
     provider_listeners = []
     for listener in db_listeners:
-        provider_listener = db_listener_to_provider_listener(
-            listener, for_delete=for_delete)
+        provider_listener = db_listener_to_provider_listener(listener)
         provider_listeners.append(provider_listener)
     return provider_listeners
 
 
-def db_listener_to_provider_listener(db_listener, for_delete=False):
+def db_listener_to_provider_listener(db_listener):
     new_listener_dict = listener_dict_to_provider_dict(
-        db_listener.to_dict(recurse=True), for_delete=for_delete)
+        db_listener.to_dict(recurse=True))
     if ('default_pool' in new_listener_dict and
             new_listener_dict['default_pool']):
-        provider_pool = db_pool_to_provider_pool(db_listener.default_pool,
-                                                 for_delete=for_delete)
+        provider_pool = db_pool_to_provider_pool(db_listener.default_pool)
         new_listener_dict['default_pool_id'] = provider_pool.pool_id
         new_listener_dict['default_pool'] = provider_pool
     if new_listener_dict.get('l7policies', None):
@@ -172,26 +184,18 @@ def db_listener_to_provider_listener(db_listener, for_delete=False):
     return provider_listener
 
 
-def _get_secret_data(cert_manager, project_id, secret_ref, for_delete=False):
+def _get_secret_data(cert_manager, project_id, secret_ref):
     """Get the secret from the certificate manager and upload it to the amp.
 
     :returns: The secret data.
     """
     context = oslo_context.RequestContext(project_id=project_id)
-    try:
-        secret_data = cert_manager.get_secret(context, secret_ref)
-    except Exception as e:
-        LOG.warning('Unable to retrieve certificate: %s due to %s.',
-                    secret_ref, str(e))
-        if for_delete:
-            secret_data = None
-        else:
-            raise exceptions.CertificateRetrievalException(ref=secret_ref)
-    return secret_data
+    return cert_manager.get_secret(context, secret_ref)
 
 
-def listener_dict_to_provider_dict(listener_dict, for_delete=False):
-    new_listener_dict = _base_to_provider_dict(listener_dict)
+def listener_dict_to_provider_dict(listener_dict):
+    new_listener_dict = _base_to_provider_dict(listener_dict,
+                                               include_project_id=True)
     new_listener_dict['listener_id'] = new_listener_dict.pop('id')
     if 'load_balancer_id' in new_listener_dict:
         new_listener_dict['loadbalancer_id'] = new_listener_dict.pop(
@@ -202,8 +206,15 @@ def listener_dict_to_provider_dict(listener_dict, for_delete=False):
         new_listener_dict['default_tls_container_ref'] = new_listener_dict.pop(
             'tls_certificate_id')
     if 'sni_containers' in new_listener_dict:
-        new_listener_dict['sni_container_refs'] = new_listener_dict.pop(
-            'sni_containers')
+        sni_refs = []
+        sni_containers = new_listener_dict.pop('sni_containers')
+        for sni in sni_containers:
+            if 'tls_container_id' in sni:
+                sni_refs.append(sni['tls_container_id'])
+            else:
+                raise exceptions.ValidationException(
+                    detail=_('Invalid SNI container on listener'))
+        new_listener_dict['sni_container_refs'] = sni_refs
     if 'sni_container_refs' in listener_dict:
         listener_dict['sni_containers'] = listener_dict.pop(
             'sni_container_refs')
@@ -219,6 +230,8 @@ def listener_dict_to_provider_dict(listener_dict, for_delete=False):
         SNI_objs = []
         for sni in listener_obj.sni_containers:
             if isinstance(sni, dict):
+                if 'listener' in sni:
+                    del sni['listener']
                 sni_obj = data_models.SNI(**sni)
                 SNI_objs.append(sni_obj)
             elif isinstance(sni, six.string_types):
@@ -233,23 +246,15 @@ def listener_dict_to_provider_dict(listener_dict, for_delete=False):
             name=CONF.certificates.cert_manager,
             invoke_on_load=True,
         ).driver
-        try:
-            cert_dict = cert_parser.load_certificates_data(cert_manager,
-                                                           listener_obj)
-        except Exception as e:
-            with excutils.save_and_reraise_exception() as ctxt:
-                LOG.warning('Unable to retrieve certificate(s) due to %s.',
-                            str(e))
-                if for_delete:
-                    ctxt.reraise = False
-                    cert_dict = {}
+        cert_dict = cert_parser.load_certificates_data(cert_manager,
+                                                       listener_obj)
         if 'tls_cert' in cert_dict and cert_dict['tls_cert']:
             new_listener_dict['default_tls_container_data'] = (
-                cert_dict['tls_cert'].to_dict())
+                cert_dict['tls_cert'].to_dict(recurse=True))
         if 'sni_certs' in cert_dict and cert_dict['sni_certs']:
             sni_data_list = []
             for sni in cert_dict['sni_certs']:
-                sni_data_list.append(sni.to_dict())
+                sni_data_list.append(sni.to_dict(recurse=True))
             new_listener_dict['sni_container_data'] = sni_data_list
 
         if listener_obj.client_ca_tls_certificate_id:
@@ -261,6 +266,14 @@ def listener_dict_to_provider_dict(listener_dict, for_delete=False):
                                         listener_obj.client_crl_container_id)
             new_listener_dict['client_crl_container_data'] = crl_file
 
+    # Format the allowed_cidrs
+    if ('allowed_cidrs' in new_listener_dict and
+            new_listener_dict['allowed_cidrs'] and
+            'cidr' in new_listener_dict['allowed_cidrs'][0]):
+        cidrs_dict_list = new_listener_dict.pop('allowed_cidrs')
+        new_listener_dict['allowed_cidrs'] = [cidr_dict['cidr'] for
+                                              cidr_dict in cidrs_dict_list]
+
     # Remove the DB back references
     if 'load_balancer' in new_listener_dict:
         del new_listener_dict['load_balancer']
@@ -274,11 +287,10 @@ def listener_dict_to_provider_dict(listener_dict, for_delete=False):
     if ('default_pool' in new_listener_dict and
             new_listener_dict['default_pool']):
         pool = new_listener_dict.pop('default_pool')
-        new_listener_dict['default_pool'] = pool_dict_to_provider_dict(
-            pool, for_delete=for_delete)
+        new_listener_dict['default_pool'] = pool_dict_to_provider_dict(pool)
     provider_l7policies = []
     if 'l7policies' in new_listener_dict:
-        l7policies = new_listener_dict.pop('l7policies')
+        l7policies = new_listener_dict.pop('l7policies') or []
         for l7policy in l7policies:
             provider_l7policy = l7policy_dict_to_provider_dict(l7policy)
             provider_l7policies.append(provider_l7policy)
@@ -286,17 +298,15 @@ def listener_dict_to_provider_dict(listener_dict, for_delete=False):
     return new_listener_dict
 
 
-def db_pools_to_provider_pools(db_pools, for_delete=False):
+def db_pools_to_provider_pools(db_pools):
     provider_pools = []
     for pool in db_pools:
-        provider_pools.append(db_pool_to_provider_pool(pool,
-                                                       for_delete=for_delete))
+        provider_pools.append(db_pool_to_provider_pool(pool))
     return provider_pools
 
 
-def db_pool_to_provider_pool(db_pool, for_delete=False):
-    new_pool_dict = pool_dict_to_provider_dict(db_pool.to_dict(recurse=True),
-                                               for_delete=for_delete)
+def db_pool_to_provider_pool(db_pool):
+    new_pool_dict = pool_dict_to_provider_dict(db_pool.to_dict(recurse=True))
     # Replace the sub-dicts with objects
     if 'health_monitor' in new_pool_dict:
         del new_pool_dict['health_monitor']
@@ -315,8 +325,8 @@ def db_pool_to_provider_pool(db_pool, for_delete=False):
     return driver_dm.Pool.from_dict(new_pool_dict)
 
 
-def pool_dict_to_provider_dict(pool_dict, for_delete=False):
-    new_pool_dict = _base_to_provider_dict(pool_dict)
+def pool_dict_to_provider_dict(pool_dict):
+    new_pool_dict = _base_to_provider_dict(pool_dict, include_project_id=True)
     new_pool_dict['pool_id'] = new_pool_dict.pop('id')
 
     # Pull the certs out of the certificate manager to pass to the provider
@@ -338,19 +348,11 @@ def pool_dict_to_provider_dict(pool_dict, for_delete=False):
             name=CONF.certificates.cert_manager,
             invoke_on_load=True,
         ).driver
-        try:
-            cert_dict = cert_parser.load_certificates_data(cert_manager,
-                                                           pool_obj)
-        except Exception as e:
-            with excutils.save_and_reraise_exception() as ctxt:
-                LOG.warning('Unable to retrieve certificate(s) due to %s.',
-                            str(e))
-                if for_delete:
-                    ctxt.reraise = False
-                    cert_dict = {}
+        cert_dict = cert_parser.load_certificates_data(cert_manager,
+                                                       pool_obj)
         if 'tls_cert' in cert_dict and cert_dict['tls_cert']:
             new_pool_dict['tls_container_data'] = (
-                cert_dict['tls_cert'].to_dict())
+                cert_dict['tls_cert'].to_dict(recurse=True))
 
         if pool_obj.ca_tls_certificate_id:
             cert = _get_secret_data(cert_manager, pool_obj.project_id,
@@ -378,9 +380,12 @@ def pool_dict_to_provider_dict(pool_dict, for_delete=False):
     if 'load_balancer_id' in new_pool_dict:
         new_pool_dict['loadbalancer_id'] = new_pool_dict.pop(
             'load_balancer_id')
-    if 'health_monitor' in new_pool_dict and new_pool_dict['health_monitor']:
+    if 'health_monitor' in new_pool_dict:
         hm = new_pool_dict.pop('health_monitor')
-        new_pool_dict['healthmonitor'] = hm_dict_to_provider_dict(hm)
+        if hm:
+            new_pool_dict['healthmonitor'] = hm_dict_to_provider_dict(hm)
+        else:
+            new_pool_dict['healthmonitor'] = None
     if 'members' in new_pool_dict and new_pool_dict['members']:
         members = new_pool_dict.pop('members')
         provider_members = []
@@ -404,7 +409,8 @@ def db_member_to_provider_member(db_member):
 
 
 def member_dict_to_provider_dict(member_dict):
-    new_member_dict = _base_to_provider_dict(member_dict)
+    new_member_dict = _base_to_provider_dict(member_dict,
+                                             include_project_id=True)
     new_member_dict['member_id'] = new_member_dict.pop('id')
     if 'ip_address' in new_member_dict:
         new_member_dict['address'] = new_member_dict.pop('ip_address')
@@ -420,7 +426,7 @@ def db_HM_to_provider_HM(db_hm):
 
 
 def hm_dict_to_provider_dict(hm_dict):
-    new_hm_dict = _base_to_provider_dict(hm_dict)
+    new_hm_dict = _base_to_provider_dict(hm_dict, include_project_id=True)
     new_hm_dict['healthmonitor_id'] = new_hm_dict.pop('id')
     if 'fall_threshold' in new_hm_dict:
         new_hm_dict['max_retries_down'] = new_hm_dict.pop('fall_threshold')
@@ -451,7 +457,8 @@ def db_l7policy_to_provider_l7policy(db_l7policy):
 
 
 def l7policy_dict_to_provider_dict(l7policy_dict):
-    new_l7policy_dict = _base_to_provider_dict(l7policy_dict)
+    new_l7policy_dict = _base_to_provider_dict(l7policy_dict,
+                                               include_project_id=True)
     new_l7policy_dict['l7policy_id'] = new_l7policy_dict.pop('id')
     # Remove the DB back references
     if 'listener' in new_l7policy_dict:
@@ -482,7 +489,8 @@ def db_l7rule_to_provider_l7rule(db_l7rule):
 
 
 def l7rule_dict_to_provider_dict(l7rule_dict):
-    new_l7rule_dict = _base_to_provider_dict(l7rule_dict)
+    new_l7rule_dict = _base_to_provider_dict(l7rule_dict,
+                                             include_project_id=True)
     new_l7rule_dict['l7rule_id'] = new_l7rule_dict.pop('id')
     # Remove the DB back references
     if 'l7policy' in new_l7rule_dict:
