@@ -31,6 +31,7 @@ from octavia.common import constants
 from octavia.common import data_models
 from octavia.common import exceptions
 from octavia.common import stats
+from octavia.common import utils as common_utils
 from octavia.db import api as db_api
 from octavia.db import prepare as db_prepare
 from octavia.i18n import _
@@ -115,7 +116,11 @@ class ListenersController(base.BaseController):
         if not db_pool:
             raise exceptions.NotFound(
                 resource=data_models.Pool._name(), id=pool_id)
-        self._validate_protocol(listener_protocol, db_pool.protocol)
+        if (db_pool.protocol == constants.PROTOCOL_UDP and
+                db_pool.protocol != listener_protocol):
+            msg = _("Listeners of type %s can only have pools of "
+                    "type UDP.") % constants.PROTOCOL_UDP
+            raise exceptions.ValidationException(detail=msg)
 
     def _has_tls_container_refs(self, listener_dict):
         return (listener_dict.get('tls_certificate_id') or
@@ -127,11 +132,6 @@ class ListenersController(base.BaseController):
                 listener_dict.get('insert_headers'))
 
     def _validate_insert_headers(self, insert_header_list, listener_protocol):
-        if (listener_protocol not in
-                constants.LISTENER_PROTOCOLS_SUPPORTING_HEADER_INSERTION):
-            raise exceptions.InvalidOption(
-                value='insert-headers',
-                option=('a %s protocol listener.' % listener_protocol))
         if list(set(insert_header_list) - (
                 set(constants.SUPPORTED_HTTP_HEADERS +
                     constants.SUPPORTED_SSL_HEADERS))):
@@ -152,6 +152,15 @@ class ListenersController(base.BaseController):
                     value=headers,
                     option=('%s protocol listener.' % listener_protocol))
 
+    def _validate_cidr_compatible_with_vip(self, vip, allowed_cidrs):
+        for cidr in allowed_cidrs:
+            # Check if CIDR IP version matches VIP IP version
+            if common_utils.is_cidr_ipv6(cidr) != common_utils.is_ipv6(vip):
+                msg = _("CIDR %(cidr)s IP version incompatible with VIP "
+                        "%(vip)s IP version.")
+                raise exceptions.ValidationException(
+                    detail=msg % {'cidr': cidr, 'vip': vip})
+
     def _validate_create_listener(self, lock_session, listener_dict):
         """Validate listener for wrong protocol or duplicate listeners
 
@@ -166,9 +175,9 @@ class ListenersController(base.BaseController):
         # Check for UDP compatibility
         if (listener_protocol == constants.PROTOCOL_UDP and
                 self._is_tls_or_insert_header(listener_dict)):
-            raise exceptions.ValidationException(
-                detail=_("%s protocol listener does not "
-                         "support TLS.") % constants.PROTOCOL_UDP)
+            raise exceptions.ValidationException(detail=_(
+                "%s protocol listener does not support TLS or header "
+                "insertion.") % constants.PROTOCOL_UDP)
 
         # Check for TLS disabled
         if (not CONF.api_settings.allow_tls_terminated_listeners and
@@ -230,6 +239,48 @@ class ListenersController(base.BaseController):
                 listener_dict.get('client_ca_tls_certificate_id'),
                 listener_dict.get('client_crl_container_id', None))
 
+        # Validate that the L4 protocol (UDP or TCP) is not already used for
+        # the specified protocol_port in this load balancer
+        pcontext = pecan.request.context
+        query_filter = {
+            'project_id': listener_dict['project_id'],
+            'load_balancer_id': listener_dict['load_balancer_id'],
+            'protocol_port': listener_dict['protocol_port']
+        }
+
+        # Get listeners on the same load balancer that use the same
+        # protocol port
+        db_listeners = self.repositories.listener.get_all_API_list(
+            lock_session, show_deleted=False,
+            pagination_helper=pcontext.get(constants.PAGINATION_HELPER),
+            **query_filter)[0]
+
+        if db_listeners:
+            l4_protocol = constants.L4_PROTOCOL_MAP[listener_protocol]
+
+            # List supported protocols that share the same L4 protocol as our
+            # new listener
+            disallowed_protocols = [
+                p
+                for p in constants.L4_PROTOCOL_MAP
+                if constants.L4_PROTOCOL_MAP[p] == l4_protocol
+            ]
+
+            for db_l in db_listeners:
+                # Check if l4 protocol ports conflict
+                if db_l.protocol in disallowed_protocols:
+                    raise exceptions.DuplicateListenerEntry(
+                        protocol=db_l.protocol,
+                        port=listener_dict.get('protocol_port'))
+
+        # Validate allowed CIDRs
+        allowed_cidrs = listener_dict.get('allowed_cidrs', []) or []
+        lb_id = listener_dict.get('load_balancer_id')
+        vip_db = self.repositories.vip.get(
+            lock_session, load_balancer_id=lb_id)
+        vip_address = vip_db.ip_address
+        self._validate_cidr_compatible_with_vip(vip_address, allowed_cidrs)
+
         try:
             db_listener = self.repositories.listener.create(
                 lock_session, **listener_dict)
@@ -239,17 +290,20 @@ class ListenersController(base.BaseController):
                                 'tls_container_id': container.get(
                                     'tls_container_id')}
                     self.repositories.sni.create(lock_session, **sni_dict)
+                # DB listener needs to be refreshed
                 db_listener = self.repositories.listener.get(
                     lock_session, id=db_listener.id)
+
             return db_listener
         except odb_exceptions.DBDuplicateEntry as de:
-            column_list = ['load_balancer_id', 'protocol_port']
+            column_list = ['load_balancer_id', 'protocol', 'protocol_port']
             constraint_list = ['uq_listener_load_balancer_id_protocol_port']
             if ['id'] == de.columns:
                 raise exceptions.IDAlreadyExists()
-            elif (set(column_list) == set(de.columns) or
-                  set(constraint_list) == set(de.columns)):
+            if (set(column_list) == set(de.columns) or
+                    set(constraint_list) == set(de.columns)):
                 raise exceptions.DuplicateListenerEntry(
+                    protocol=listener_dict.get('protocol'),
                     port=listener_dict.get('protocol_port'))
         except odb_exceptions.DBError:
             raise exceptions.InvalidOption(value=listener_dict.get('protocol'),
@@ -302,7 +356,9 @@ class ListenersController(base.BaseController):
 
             # re-inject the sni container references lost due to SNI
             # being a separate table in the DB
-            provider_listener.sni_container_refs = listener.sni_container_refs
+            if listener.sni_container_refs != wtypes.Unset:
+                provider_listener.sni_container_refs = (
+                    listener.sni_container_refs)
 
             # Dispatch to the driver
             LOG.info("Sending create Listener %s to provider %s",
@@ -389,7 +445,7 @@ class ListenersController(base.BaseController):
                 list(listener.insert_headers.keys()), db_listener.protocol)
 
         sni_containers = listener.sni_container_refs or []
-        tls_refs = [sni for sni in sni_containers]
+        tls_refs = list(sni_containers)
         if listener.default_tls_container_ref:
             tls_refs.append(listener.default_tls_container_ref)
         self._validate_tls_refs(tls_refs)
@@ -416,6 +472,12 @@ class ListenersController(base.BaseController):
         if ca_ref or crl_ref:
             self._validate_client_ca_and_crl_refs(ca_ref, crl_ref)
 
+        # Validate allowed CIDRs
+        if (listener.allowed_cidrs and listener.allowed_cidrs != wtypes.Unset):
+            vip_address = db_listener.load_balancer.vip.ip_address
+            self._validate_cidr_compatible_with_vip(
+                vip_address, listener.allowed_cidrs)
+
     def _set_default_on_none(self, listener):
         """Reset settings to their default values if None/null was passed in
 
@@ -477,20 +539,20 @@ class ListenersController(base.BaseController):
             # Prepare the data for the driver data model
             listener_dict = listener.to_dict(render_unsets=False)
             listener_dict['id'] = id
+
             provider_listener_dict = (
                 driver_utils.listener_dict_to_provider_dict(listener_dict))
 
             # Also prepare the baseline object data
-            old_provider_listener = (
-                driver_utils.db_listener_to_provider_listener(db_listener,
-                                                              for_delete=True))
+            old_provider_llistener = (
+                driver_utils.db_listener_to_provider_listener(db_listener))
 
             # Dispatch to the driver
             LOG.info("Sending update Listener %s to provider %s", id,
                      driver.name)
             driver_utils.call_provider(
                 driver.name, driver.listener_update,
-                old_provider_listener,
+                old_provider_llistener,
                 driver_dm.Listener.from_dict(provider_listener_dict))
 
             # Update the database to reflect what the driver just accepted
@@ -530,8 +592,7 @@ class ListenersController(base.BaseController):
             LOG.info("Sending delete Listener %s to provider %s", id,
                      driver.name)
             provider_listener = (
-                driver_utils.db_listener_to_provider_listener(
-                    db_listener, for_delete=True))
+                driver_utils.db_listener_to_provider_listener(db_listener))
             driver_utils.call_provider(driver.name, driver.listener_delete,
                                        provider_listener)
 
