@@ -136,14 +136,13 @@ class PoolsController(base.BaseController):
     def _is_only_specified_in_request(self, request, **kwargs):
         request_attrs = []
         check_attrs = kwargs['check_exist_attrs']
-        escaped_attrs = ['from_data_model', 'translate_key_to_data_model',
+        escaped_attrs = ['from_data_model',
                          'translate_dict_keys_to_data_model', 'to_dict']
 
         for attr in dir(request):
             if attr.startswith('_') or attr in escaped_attrs:
                 continue
-            else:
-                request_attrs.append(attr)
+            request_attrs.append(attr)
 
         for req_attr in request_attrs:
             if (getattr(request, req_attr) and req_attr not in check_attrs):
@@ -163,11 +162,11 @@ class PoolsController(base.BaseController):
                     "only accepts: type, persistence_timeout, "
                     "persistence_granularity.") % (
                         constants.SESSION_PERSISTENCE_SOURCE_IP))
-            elif request.session_persistence.cookie_name:
+            if request.session_persistence.cookie_name:
                 raise exceptions.ValidationException(detail=_(
                     "Cookie names are not supported for %s pools.") %
                     constants.PROTOCOL_UDP)
-            elif request.session_persistence.type in [
+            if request.session_persistence.type in [
                 constants.SESSION_PERSISTENCE_HTTP_COOKIE,
                     constants.SESSION_PERSISTENCE_APP_COOKIE]:
                 raise exceptions.ValidationException(detail=_(
@@ -190,7 +189,15 @@ class PoolsController(base.BaseController):
         # pool_dict:
         pool = pool_.pool
         context = pecan.request.context.get('octavia_context')
-        listener = None
+        if pool.protocol == constants.PROTOCOL_UDP:
+            self._validate_pool_request_for_udp(pool)
+        else:
+            if (pool.session_persistence and (
+                    pool.session_persistence.persistence_timeout or
+                    pool.session_persistence.persistence_granularity)):
+                raise exceptions.ValidationException(detail=_(
+                    "persistence_timeout and persistence_granularity "
+                    "is only for UDP protocol pools."))
         if pool.loadbalancer_id:
             pool.project_id, provider = self._get_lb_project_id_provider(
                 context.session, pool.loadbalancer_id)
@@ -208,19 +215,6 @@ class PoolsController(base.BaseController):
         self._auth_validate_action(context, pool.project_id,
                                    constants.RBAC_POST)
 
-        if pool.listener_id and listener:
-            self._validate_protocol(listener.protocol, pool.protocol)
-
-        if pool.protocol == constants.PROTOCOL_UDP:
-            self._validate_pool_request_for_udp(pool)
-        else:
-            if (pool.session_persistence and (
-                    pool.session_persistence.persistence_timeout or
-                    pool.session_persistence.persistence_granularity)):
-                raise exceptions.ValidationException(detail=_(
-                    "persistence_timeout and persistence_granularity "
-                    "is only for UDP protocol pools."))
-
         if pool.session_persistence:
             sp_dict = pool.session_persistence.to_dict(render_unsets=False)
             validate.check_session_persistence(sp_dict)
@@ -409,7 +403,7 @@ class PoolsController(base.BaseController):
 
             # Also prepare the baseline object data
             old_provider_pool = driver_utils.db_pool_to_provider_pool(
-                db_pool, for_delete=True)
+                db_pool)
 
             # Dispatch to the driver
             LOG.info("Sending update Pool %s to provider %s", id, driver.name)
@@ -436,16 +430,15 @@ class PoolsController(base.BaseController):
         """Deletes a pool from a load balancer."""
         context = pecan.request.context.get('octavia_context')
         db_pool = self._get_db_pool(context.session, id, show_deleted=False)
+        if db_pool.l7policies:
+            raise exceptions.PoolInUseByL7Policy(
+                id=db_pool.id, l7policy_id=db_pool.l7policies[0].id)
 
         project_id, provider = self._get_lb_project_id_provider(
             context.session, db_pool.load_balancer_id)
 
         self._auth_validate_action(context, project_id, constants.RBAC_DELETE)
 
-        if db_pool.l7policies:
-            raise exceptions.PoolInUseByL7Policy(
-                id=db_pool.id, l7policy_id=db_pool.l7policies[0].id)
-
         # Load the driver early as it also provides validation
         driver = driver_factory.get_driver(provider)
 
@@ -459,8 +452,7 @@ class PoolsController(base.BaseController):
 
             LOG.info("Sending delete Pool %s to provider %s", id, driver.name)
             provider_pool = (
-                driver_utils.db_pool_to_provider_pool(db_pool,
-                                                      for_delete=True))
+                driver_utils.db_pool_to_provider_pool(db_pool))
             driver_utils.call_provider(driver.name, driver.pool_delete,
                                        provider_pool)
 
