@@ -24,6 +24,8 @@ class SessionPersistenceResponse(types.BaseType):
     """Defines which attributes are to be shown on any response."""
     type = wtypes.wsattr(wtypes.text)
     cookie_name = wtypes.wsattr(wtypes.text)
+    persistence_timeout = wtypes.wsattr(wtypes.IntegerType())
+    persistence_granularity = wtypes.wsattr(types.IPAddressType())
 
 
 class SessionPersistencePOST(types.BaseType):
@@ -32,6 +34,9 @@ class SessionPersistencePOST(types.BaseType):
                          mandatory=True)
     cookie_name = wtypes.wsattr(wtypes.StringType(max_length=255),
                                 default=None)
+    persistence_timeout = wtypes.wsattr(wtypes.IntegerType(), default=None)
+    persistence_granularity = wtypes.wsattr(types.IPAddressType(),
+                                            default=None)
 
 
 class SessionPersistencePUT(types.BaseType):
@@ -39,12 +44,18 @@ class SessionPersistencePUT(types.BaseType):
     type = wtypes.wsattr(wtypes.Enum(str, *constants.SUPPORTED_SP_TYPES))
     cookie_name = wtypes.wsattr(wtypes.StringType(max_length=255),
                                 default=None)
+    persistence_timeout = wtypes.wsattr(wtypes.IntegerType(), default=None)
+    persistence_granularity = wtypes.wsattr(types.IPAddressType(),
+                                            default=None)
 
 
 class BasePoolType(types.BaseType):
     _type_to_model_map = {'admin_state_up': 'enabled',
                           'healthmonitor': 'health_monitor',
-                          'healthmonitor_id': 'health_monitor.id'}
+                          'healthmonitor_id': 'health_monitor.id',
+                          'tls_container_ref': 'tls_certificate_id',
+                          'ca_tls_container_ref': 'ca_tls_certificate_id',
+                          'crl_container_ref': 'crl_container_id'}
 
     _child_map = {'health_monitor': {'id': 'healthmonitor_id'}}
 
@@ -67,6 +78,11 @@ class PoolResponse(BasePoolType):
     updated_at = wtypes.wsattr(wtypes.datetime.datetime)
     healthmonitor_id = wtypes.wsattr(wtypes.UuidType())
     members = wtypes.wsattr([types.IdOnlyType])
+    tags = wtypes.wsattr(wtypes.ArrayType(wtypes.StringType()))
+    tls_container_ref = wtypes.wsattr(wtypes.StringType())
+    ca_tls_container_ref = wtypes.wsattr(wtypes.StringType())
+    crl_container_ref = wtypes.wsattr(wtypes.StringType())
+    tls_enabled = wtypes.wsattr(bool)
 
     @classmethod
     def from_data_model(cls, data_model, children=False):
@@ -93,7 +109,6 @@ class PoolResponse(BasePoolType):
             member_model = types.IdOnlyType
             if data_model.health_monitor:
                 pool.healthmonitor_id = data_model.health_monitor.id
-
         pool.listeners = [
             types.IdOnlyType.from_data_model(i) for i in data_model.listeners]
         pool.members = [
@@ -137,6 +152,12 @@ class PoolPOST(BasePoolType):
     project_id = wtypes.wsattr(wtypes.StringType(max_length=36))
     healthmonitor = wtypes.wsattr(health_monitor.HealthMonitorSingleCreate)
     members = wtypes.wsattr([member.MemberSingleCreate])
+    tags = wtypes.wsattr(wtypes.ArrayType(wtypes.StringType(max_length=255)))
+    tls_container_ref = wtypes.wsattr(
+        wtypes.StringType(max_length=255))
+    ca_tls_container_ref = wtypes.wsattr(wtypes.StringType(max_length=255))
+    crl_container_ref = wtypes.wsattr(wtypes.StringType(max_length=255))
+    tls_enabled = wtypes.wsattr(bool, default=False)
 
 
 class PoolRootPOST(types.BaseType):
@@ -151,6 +172,11 @@ class PoolPUT(BasePoolType):
     lb_algorithm = wtypes.wsattr(
         wtypes.Enum(str, *constants.SUPPORTED_LB_ALGORITHMS))
     session_persistence = wtypes.wsattr(SessionPersistencePUT)
+    tags = wtypes.wsattr(wtypes.ArrayType(wtypes.StringType(max_length=255)))
+    tls_container_ref = wtypes.wsattr(wtypes.StringType(max_length=255))
+    ca_tls_container_ref = wtypes.wsattr(wtypes.StringType(max_length=255))
+    crl_container_ref = wtypes.wsattr(wtypes.StringType(max_length=255))
+    tls_enabled = wtypes.wsattr(bool)
 
 
 class PoolRootPut(types.BaseType):
@@ -168,6 +194,11 @@ class PoolSingleCreate(BasePoolType):
     session_persistence = wtypes.wsattr(SessionPersistencePOST)
     healthmonitor = wtypes.wsattr(health_monitor.HealthMonitorSingleCreate)
     members = wtypes.wsattr([member.MemberSingleCreate])
+    tags = wtypes.wsattr(wtypes.ArrayType(wtypes.StringType(max_length=255)))
+    tls_container_ref = wtypes.wsattr(wtypes.StringType(max_length=255))
+    ca_tls_container_ref = wtypes.wsattr(wtypes.StringType(max_length=255))
+    crl_container_ref = wtypes.wsattr(wtypes.StringType(max_length=255))
+    tls_enabled = wtypes.wsattr(bool, default=False)
 
 
 class PoolStatusResponse(BasePoolType):
