@@ -205,14 +205,6 @@ DOMAIN_NAME = 'domain_name'
 UPDATE_STATS = 'UPDATE_STATS'
 UPDATE_HEALTH = 'UPDATE_HEALTH'
 
-VALID_LISTENER_POOL_PROTOCOL_MAP = {
-    PROTOCOL_TCP: [PROTOCOL_HTTP, PROTOCOL_HTTPS,
-                   PROTOCOL_PROXY, PROTOCOL_TCP],
-    PROTOCOL_HTTP: [PROTOCOL_HTTP, PROTOCOL_PROXY],
-    PROTOCOL_HTTPS: [PROTOCOL_HTTPS, PROTOCOL_PROXY, PROTOCOL_TCP],
-    PROTOCOL_TERMINATED_HTTPS: [PROTOCOL_HTTP, PROTOCOL_PROXY],
-    PROTOCOL_UDP: [PROTOCOL_UDP]}
-
 # API Integer Ranges
 MIN_PORT_NUMBER = 1
 MAX_PORT_NUMBER = 65535
@@ -288,76 +280,97 @@ HTTP_QUOTED_HEADER_VALUE_REGEX = (r'\A"[a-zA-Z0-9 \t'
 DOMAIN_NAME_REGEX = (
     r'^(?=.{1,253}\.?$)(?:(?!-|[^.]+_)[A-Za-z0-9-_]{1,63}(?<!-)(?:\.|$))+$')
 
+# TaskFlow
+SUPPORTED_TASKFLOW_ENGINE_TYPES = ['serial', 'parallel']
+
 # Task/Flow constants
+ACTIVE_CONNECTIONS = 'active_connections'
+ADDED_PORTS = 'added_ports'
+AMP_DATA = 'amp_data'
 AMPHORA = 'amphora'
-FAILED_AMPHORA = 'failed_amphora'
-FAILOVER_AMPHORA = 'failover_amphora'
-AMPHORAE = 'amphorae'
 AMPHORA_ID = 'amphora_id'
 AMPHORA_INDEX = 'amphora_index'
-FAILOVER_AMPHORA_ID = 'failover_amphora_id'
+AMPHORA_NETWORK_CONFIG = 'amphora_network_config'
+AMPHORAE = 'amphorae'
+AMPHORAE_NETWORK_CONFIG = 'amphorae_network_config'
+AMPS_DATA = 'amps_data'
+ANTI_AFFINITY = 'anti-affinity'
+BYTES_IN = 'bytes_in'
+BYTES_OUT = 'bytes_out'
+CA_TLS_CERTIFICATE_ID = 'ca_tls_certificate_id'
+CLIENT_CA_TLS_CERTIFICATE_ID = 'client_ca_tls_certificate_id'
+CLIENT_CRL_CONTAINER_ID = 'client_crl_container_id'
+COMPUTE_ID = 'compute_id'
+COMPUTE_OBJ = 'compute_obj'
+CONN_MAX_RETRIES = 'conn_max_retries'
+CONN_RETRY_INTERVAL = 'conn_retry_interval'
+CREATED_AT = 'created_at'
+CRL_CONTAINER_ID = 'crl_container_id'
 DELTA = 'delta'
 DELTAS = 'deltas'
-DESCRIPTION = 'description'
-FIELDS = 'fields'
+ENABLED = 'enabled'
+FAILED_AMPHORA = 'failed_amphora'
+FAILOVER_AMPHORA = 'failover_amphora'
+FAILOVER_AMPHORA_ID = 'failover_amphora_id'
+FLAVOR_ID = 'flavor_id'
 HEALTH_MON = 'health_mon'
 HEALTH_MONITOR = 'health_monitor'
+HEALTH_MONITOR_ID = 'health_monitor_id'
+HEALTH_MONITOR_UPDATES = 'health_monitor_updates'
+IP_ADDRESS = 'ip_address'
+L7POLICY = 'l7policy'
+L7POLICY_ID = 'l7policy_id'
+L7POLICY_UPDATES = 'l7policy_updates'
+L7RULE = 'l7rule'
+L7RULE_ID = 'l7rule_id'
+L7RULE_UPDATES = 'l7rule_updates'
 LISTENER = 'listener'
 LISTENER_ID = 'listener_id'
+LISTENER_UPDATES = 'listener_updates'
 LOADBALANCER = 'loadbalancer'
 LOADBALANCER_ID = 'loadbalancer_id'
 LOAD_BALANCER_ID = 'load_balancer_id'
-SERVER_GROUP_ID = 'server_group_id'
-ANTI_AFFINITY = 'anti-affinity'
-SOFT_ANTI_AFFINITY = 'soft-anti-affinity'
+LOAD_BALANCER_UPDATES = 'load_balancer_updates'
 MEMBER = 'member'
 MEMBER_ID = 'member_id'
-COMPUTE_ID = 'compute_id'
-COMPUTE_OBJ = 'compute_obj'
-AMP_DATA = 'amp_data'
-AMPS_DATA = 'amps_data'
+MEMBER_PORTS = 'member_ports'
+MEMBER_UPDATES = 'member_updates'
+NAME = 'name'
+NETWORK_ID = 'network_id'
 NICS = 'nics'
-VIP = 'vip'
+OBJECT = 'object'
+PEER_PORT = 'peer_port'
 POOL = 'pool'
 POOL_CHILD_COUNT = 'pool_child_count'
 POOL_ID = 'pool_id'
-L7POLICY = 'l7policy'
-L7RULE = 'l7rule'
-OBJECT = 'object'
-SERVER_PEM = 'server_pem'
-UPDATE_DICT = 'update_dict'
-VIP_NETWORK = 'vip_network'
-AMPHORA_NETWORK_CONFIG = 'amphora_network_config'
-AMPHORAE_NETWORK_CONFIG = 'amphorae_network_config'
-ADDED_PORTS = 'added_ports'
-PORTS = 'ports'
-MEMBER_PORTS = 'member_ports'
-TOPOLOGY = 'topology'
-HEALTH_MONITOR_ID = 'health_monitor_id'
-L7POLICY_ID = 'l7policy_id'
-L7RULE_ID = 'l7rule_id'
-LOAD_BALANCER_UPDATES = 'load_balancer_updates'
-LISTENER_UPDATES = 'listener_updates'
 POOL_UPDATES = 'pool_updates'
-MEMBER_UPDATES = 'member_updates'
-HEALTH_MONITOR_UPDATES = 'health_monitor_updates'
-L7POLICY_UPDATES = 'l7policy_updates'
-L7RULE_UPDATES = 'l7rule_updates'
-TIMEOUT_DICT = 'timeout_dict'
+PORT_ID = 'port_id'
+PORTS = 'ports'
+PROVIDER = 'provider'
+PROVIDER_NAME = 'provider_name'
+QOS_POLICY_ID = 'qos_policy_id'
+REDIRECT_POOL = 'redirect_pool'
 REQ_CONN_TIMEOUT = 'req_conn_timeout'
 REQ_READ_TIMEOUT = 'req_read_timeout'
-CONN_MAX_RETRIES = 'conn_max_retries'
-CONN_RETRY_INTERVAL = 'conn_retry_interval'
-SUBNET = 'subnet'
-AMP_DATA = 'amp_data'
-ACTIVE_CONNECTIONS = 'active_connections'
-BYTES_IN = 'bytes_in'
-BYTES_OUT = 'bytes_out'
 REQUEST_ERRORS = 'request_errors'
+SERVER_GROUP_ID = 'server_group_id'
+SERVER_PEM = 'server_pem'
+SNI_CONTAINERS = 'sni_containers'
+SOFT_ANTI_AFFINITY = 'soft-anti-affinity'
+SUBNET = 'subnet'
+TAGS = 'tags'
+TIMEOUT_DICT = 'timeout_dict'
+TLS_CERTIFICATE_ID = 'tls_certificate_id'
+TLS_CONTAINER_ID = 'tls_container_id'
+TOPOLOGY = 'topology'
 TOTAL_CONNECTIONS = 'total_connections'
-NAME = 'name'
-PROVIDER_NAME = 'provider_name'
+UPDATED_AT = 'updated_at'
+UPDATE_DICT = 'update_dict'
+VIP = 'vip'
+VIP_NETWORK = 'vip_network'
+VRRP_GROUP = 'vrrp_group'
 
+# Taskflow flow and task names
 CERT_ROTATE_AMPHORA_FLOW = 'octavia-cert-rotate-amphora-flow'
 CREATE_AMPHORA_FLOW = 'octavia-create-amphora-flow'
 CREATE_AMPHORA_FOR_LB_FLOW = 'octavia-create-amp-for-lb-flow'
@@ -500,8 +513,10 @@ AUTH_HEADER_PROTOCOL_NUMBER = 51
 
 TEMPLATES = '/templates'
 AGENT_API_TEMPLATES = '/templates'
+LOGGING_TEMPLATES = '/templates'
 
 AGENT_CONF_TEMPLATE = 'amphora_agent_conf.template'
+LOGGING_CONF_TEMPLATE = '10-rsyslog.conf.template'
 USER_DATA_CONFIG_DRIVE_TEMPLATE = 'user_data_config_drive.template'
 
 OPEN = 'OPEN'
@@ -540,8 +555,6 @@ MAX_QUOTA = 2000000000
 
 API_VERSION = '0.5'
 
-NOOP_EVENT_STREAMER = 'noop_event_streamer'
-
 HAPROXY_BASE_PEER_PORT = 1025
 KEEPALIVED_JINJA2_UPSTART = 'keepalived.upstart.j2'
 KEEPALIVED_JINJA2_SYSTEMD = 'keepalived.systemd.j2'
@@ -676,3 +689,28 @@ CLIENT_AUTH_OPTIONAL = 'OPTIONAL'
 CLIENT_AUTH_MANDATORY = 'MANDATORY'
 SUPPORTED_CLIENT_AUTH_MODES = [CLIENT_AUTH_NONE, CLIENT_AUTH_OPTIONAL,
                                CLIENT_AUTH_MANDATORY]
+
+TOPIC_AMPHORA_V2 = 'octavia_provisioning_v2'
+
+HAPROXY_HTTP_PROTOCOLS = [lib_consts.PROTOCOL_HTTP,
+                          lib_consts.PROTOCOL_TERMINATED_HTTPS]
+
+# Map each supported protocol to its L4 protocol
+L4_PROTOCOL_MAP = {
+    PROTOCOL_TCP: PROTOCOL_TCP,
+    PROTOCOL_HTTP: PROTOCOL_TCP,
+    PROTOCOL_HTTPS: PROTOCOL_TCP,
+    PROTOCOL_TERMINATED_HTTPS: PROTOCOL_TCP,
+    PROTOCOL_PROXY: PROTOCOL_TCP,
+    PROTOCOL_UDP: PROTOCOL_UDP,
+}
+
+# Volume drivers
+VOLUME_NOOP_DRIVER = 'volume_noop_driver'
+SUPPORTED_VOLUME_DRIVERS = [VOLUME_NOOP_DRIVER,
+                            'volume_cinder_driver']
+
+# Cinder volume driver constants
+CINDER_STATUS_AVAILABLE = 'available'
+CINDER_STATUS_ERROR = 'error'
+CINDER_ACTION_CREATE_VOLUME = 'create volume'
