@@ -154,7 +154,8 @@ class CertificateGenerationException(OctaviaException):
 
 class DuplicateListenerEntry(APIException):
     msg = _("Another Listener on this Load Balancer "
-            "is already using protocol_port %(port)d")
+            "is already using protocol %(protocol)s "
+            "and protocol_port %(port)d")
     code = 409
 
 
@@ -389,3 +390,11 @@ class ObjectInUse(APIException):
 class ProviderFlavorMismatchError(APIException):
     msg = _("Flavor '%(flav)s' is not compatible with provider '%(prov)s'")
     code = 400
+
+
+class VolumeDeleteException(OctaviaException):
+    message = _('Failed to delete volume instance.')
+
+
+class VolumeGetException(OctaviaException):
+    message = _('Failed to retrieve volume instance.')
