@@ -106,6 +106,12 @@ def get_intermediates_pems(intermediates=None):
               X509 pem block surrounded by BEGIN CERTIFICATE,
               END CERTIFICATE block tags
     """
+    if isinstance(intermediates, six.string_types):
+        try:
+            intermediates = intermediates.encode("utf-8")
+        except UnicodeDecodeError:
+            LOG.debug("Couldn't encode intermediates string, it was probably "
+                      "in binary DER format.")
     if X509_BEG in intermediates:
         for x509Pem in _split_x509s(intermediates):
             yield _prepare_x509_cert(_get_x509_from_pem_bytes(x509Pem))
@@ -143,10 +149,9 @@ def _split_x509s(xstr):
                 curr_pem_block = []
                 inside_x509 = False
             continue
-        else:
-            if line == X509_BEG.decode('utf-8'):
-                curr_pem_block.append(line)
-                inside_x509 = True
+        if line == X509_BEG.decode('utf-8'):
+            curr_pem_block.append(line)
+            inside_x509 = True
 
 
 def _parse_pkcs7_bundle(pkcs7):
@@ -249,6 +254,8 @@ def get_host_names(certificate):
               certificate, and 'dns_names' is a list of dNSNames
               (possibly empty) from the SubjectAltNames of the certificate.
     """
+    if isinstance(certificate, six.string_types):
+        certificate = certificate.encode('utf-8')
     try:
         cert = x509.load_pem_x509_certificate(certificate,
                                               backends.default_backend())
@@ -328,54 +335,68 @@ def build_pem(tls_container):
     :param tls_container: Object container TLS certificates
     :returns: Pem encoded certificate file
     """
-    pem = [tls_container.certificate, tls_container.private_key]
+    pem = [tls_container.certificate]
+    if tls_container.private_key:
+        pem.append(tls_container.private_key)
     if tls_container.intermediates:
         pem.extend(tls_container.intermediates[:])
     return b'\n'.join(pem) + b'\n'
 
 
-def load_certificate_data(cert_mngr, cert_ref, context):
-    """Load TLS certificate data."""
-    return _map_cert_tls_container(
-        cert_mngr.get_cert(context, cert_ref, check_only=True))
-
-
-def load_certificates_data(cert_mngr, listener, context=None):
-    """Load TLS certificate data from the listener.
+def load_certificates_data(cert_mngr, obj, context=None):
+    """Load TLS certificate data from the listener/pool.
 
     return TLS_CERT and SNI_CERTS
     """
     tls_cert = None
     sni_certs = []
     if not context:
-        context = oslo_context.RequestContext(project_id=listener.project_id)
+        context = oslo_context.RequestContext(project_id=obj.project_id)
 
-    if listener.tls_certificate_id:
-        tls_cert = load_certificate_data(
-            cert_mngr, listener.tls_certificate_id, context)
-
-    if listener.sni_containers:
-        for sni_cont in listener.sni_containers:
-            cert_container = load_certificate_data(
-                cert_mngr, sni_cont.tls_container_id, context)
+    if obj.tls_certificate_id:
+        tls_cert = _map_cert_tls_container(
+            cert_mngr.get_cert(context,
+                               obj.tls_certificate_id,
+                               check_only=True))
+    if hasattr(obj, 'sni_containers') and obj.sni_containers:
+        for sni_cont in obj.sni_containers:
+            cert_container = _map_cert_tls_container(
+                cert_mngr.get_cert(context,
+                                   sni_cont.tls_container_id,
+                                   check_only=True))
             sni_certs.append(cert_container)
     return {'tls_cert': tls_cert, 'sni_certs': sni_certs}
 
 
 def _map_cert_tls_container(cert):
+    certificate = cert.get_certificate()
+    private_key = cert.get_private_key()
+    private_key_passphrase = cert.get_private_key_passphrase()
+    intermediates = cert.get_intermediates()
+    if isinstance(certificate, six.string_types):
+        certificate = certificate.encode('utf-8')
+    if isinstance(private_key, six.string_types):
+        private_key = private_key.encode('utf-8')
+    if isinstance(private_key_passphrase, six.string_types):
+        private_key_passphrase = private_key_passphrase.encode('utf-8')
+    if intermediates:
+        intermediates = [
+            (imd.encode('utf-8') if isinstance(imd, six.string_types) else imd)
+            for imd in intermediates
+        ]
+    else:
+        intermediates = []
     return data_models.TLSContainer(
         # TODO(rm_work): applying nosec here because this is not intended to be
         # secure, it's just a way to get a consistent ID. Changing this would
         # break backwards compatibility with existing loadbalancers.
-        id=hashlib.sha1(cert.get_certificate()).hexdigest(),  # nosec
-        primary_cn=get_primary_cn(cert),
-        private_key=prepare_private_key(
-            cert.get_private_key(),
-            cert.get_private_key_passphrase()),
-        certificate=cert.get_certificate(),
-        intermediates=cert.get_intermediates())
+        id=hashlib.sha1(certificate).hexdigest(),  # nosec
+        primary_cn=get_primary_cn(certificate),
+        private_key=prepare_private_key(private_key, private_key_passphrase),
+        certificate=certificate,
+        intermediates=intermediates)
 
 
 def get_primary_cn(tls_cert):
     """Returns primary CN for Certificate."""
-    return get_host_names(tls_cert.get_certificate())['cn']
+    return get_host_names(tls_cert)['cn']
