@@ -20,7 +20,6 @@
 
 import base64
 import hashlib
-import re
 import socket
 
 import netaddr
@@ -46,9 +45,7 @@ def base64_sha1_string(string_to_hash):
     # break backwards compatibility with existing loadbalancers.
     hash_str = hashlib.sha1(string_to_hash.encode('utf-8')).digest()  # nosec
     b64_str = base64.b64encode(hash_str, str.encode('_-', 'ascii'))
-    b64_sha1 = b64_str.decode('UTF-8')
-    # https://github.com/haproxy/haproxy/issues/644
-    return re.sub(r"^-", "x", b64_sha1)
+    return b64_str.decode('UTF-8')
 
 
 def get_network_driver():
@@ -67,6 +64,12 @@ def is_ipv6(ip_address):
     return ip.version == 6
 
 
+def is_cidr_ipv6(cidr):
+    """Check if CIDR is IPv6 address with subnet prefix."""
+    ip = netaddr.IPNetwork(cidr)
+    return ip.version == 6
+
+
 def is_ipv6_lla(ip_address):
     """Check if ip address is IPv6 link local address."""
     ip = netaddr.IPAddress(ip_address)
