@@ -27,10 +27,9 @@ from oslo_log import log as logging
 from oslo_serialization import jsonutils
 from oslo_utils import excutils
 from oslo_utils import uuidutils
+from sqlalchemy.orm import joinedload
 from sqlalchemy.orm import noload
 from sqlalchemy.orm import subqueryload
-from sqlalchemy.sql.expression import false
-from sqlalchemy.sql import func
 
 from octavia.common import constants as consts
 from octavia.common import data_models
@@ -215,6 +214,7 @@ class Repositories(object):
         self.pool = PoolRepository()
         self.member = MemberRepository()
         self.listener = ListenerRepository()
+        self.listener_cidr = ListenerCidrRepository()
         self.listener_stats = ListenerStatisticsRepository()
         self.amphora = AmphoraRepository()
         self.sni = SNIRepository()
@@ -412,7 +412,7 @@ class Repositories(object):
                     quotas.in_use_load_balancer = lb_count
                     return False
                 return True
-            elif _class == data_models.Listener:
+            if _class == data_models.Listener:
                 # Decide which quota to use
                 if quotas.listener is None:
                     listener_quota = CONF.quotas.default_listener_quota
@@ -433,7 +433,7 @@ class Repositories(object):
                     quotas.in_use_listener = listener_count
                     return False
                 return True
-            elif _class == data_models.Pool:
+            if _class == data_models.Pool:
                 # Decide which quota to use
                 if quotas.pool is None:
                     pool_quota = CONF.quotas.default_pool_quota
@@ -454,7 +454,7 @@ class Repositories(object):
                     quotas.in_use_pool = pool_count
                     return False
                 return True
-            elif _class == data_models.HealthMonitor:
+            if _class == data_models.HealthMonitor:
                 # Decide which quota to use
                 if quotas.health_monitor is None:
                     hm_quota = CONF.quotas.default_health_monitor_quota
@@ -475,7 +475,7 @@ class Repositories(object):
                     quotas.in_use_health_monitor = hm_count
                     return False
                 return True
-            elif _class == data_models.Member:
+            if _class == data_models.Member:
                 # Decide which quota to use
                 if quotas.member is None:
                     member_quota = CONF.quotas.default_member_quota
@@ -890,6 +890,25 @@ class SessionPersistenceRepository(BaseRepository):
             pool_id=pool_id).first())
 
 
+class ListenerCidrRepository(BaseRepository):
+    model_class = models.ListenerCidr
+
+    def create(self, session, listener_id, allowed_cidrs):
+        if allowed_cidrs:
+            with session.begin(subtransactions=True):
+                for cidr in set(allowed_cidrs):
+                    cidr_dict = {'listener_id': listener_id, 'cidr': cidr}
+                    model = self.model_class(**cidr_dict)
+                    session.add(model)
+
+    def update(self, session, listener_id, allowed_cidrs):
+        """Updates allowed CIDRs in the database by listener_id."""
+        with session.begin(subtransactions=True):
+            session.query(self.model_class).filter_by(
+                listener_id=listener_id).delete()
+            self.create(session, listener_id, allowed_cidrs)
+
+
 class PoolRepository(BaseRepository):
     model_class = models.Pool
 
@@ -994,6 +1013,7 @@ class ListenerRepository(BaseRepository):
             subqueryload(models.Listener.load_balancer),
             subqueryload(models.Listener.sni_containers),
             subqueryload(models.Listener._tags),
+            subqueryload(models.Listener.allowed_cidrs),
             noload('*'))
 
         return super(ListenerRepository, self).get_all(
@@ -1055,11 +1075,25 @@ class ListenerRepository(BaseRepository):
                 sni = models.SNI(listener_id=id,
                                  tls_certificate_id=container_ref)
                 listener_db.sni_containers.append(sni)
+            if 'allowed_cidrs' in model_kwargs:
+                # allowed_cidrs is being updated. It is either being set or
+                # unset/cleared. We need to update in DB side.
+                allowed_cidrs = model_kwargs.pop('allowed_cidrs', []) or []
+                listener_db.allowed_cidrs = []
+                if allowed_cidrs:
+                    listener_db.allowed_cidrs = [
+                        models.ListenerCidr(listener_id=id, cidr=cidr)
+                        for cidr in allowed_cidrs]
             listener_db.update(model_kwargs)
 
     def create(self, session, **model_kwargs):
         """Creates a new Listener with some validation."""
         with session.begin(subtransactions=True):
+            listener_id = model_kwargs.get('id')
+            allowed_cidrs = set(model_kwargs.pop('allowed_cidrs', []) or [])
+            model_kwargs['allowed_cidrs'] = [
+                models.ListenerCidr(listener_id=listener_id, cidr=cidr)
+                for cidr in allowed_cidrs]
             model = self.model_class(**model_kwargs)
             if model.default_pool_id:
                 model.default_pool = self._pool_check(
@@ -1071,16 +1105,6 @@ class ListenerRepository(BaseRepository):
             session.add(model)
         return model.to_data_model()
 
-    def prov_status_active_if_not_error(self, session, listener_id):
-        """Update provisioning_status to ACTIVE if not already in ERROR."""
-        with session.begin(subtransactions=True):
-            (session.query(self.model_class).filter_by(id=listener_id).
-             # Don't mark ERROR or already ACTIVE as ACTIVE
-             filter(~self.model_class.provisioning_status.in_(
-                 [consts.ERROR, consts.ACTIVE])).
-             update({self.model_class.provisioning_status: consts.ACTIVE},
-                    synchronize_session='fetch'))
-
 
 class ListenerStatisticsRepository(BaseRepository):
     model_class = models.ListenerStatistics
@@ -1193,7 +1217,10 @@ class AmphoraRepository(BaseRepository):
                 .filter(models.Amphora.status != consts.DELETED)
                 # And the LB is also not DELETED
                 .filter(models.LoadBalancer.provisioning_status !=
-                        consts.DELETED)).first()
+                        consts.DELETED)
+                # And what does this do? Some SQLAlchemy magic?
+                .options(joinedload('*'))
+            ).first()
             if db_lb:
                 return db_lb.to_data_model()
             return None
@@ -1222,12 +1249,9 @@ class AmphoraRepository(BaseRepository):
             seconds=expired_seconds)
 
         with session.begin(subtransactions=True):
-            amp = session.query(self.model_class).with_for_update().filter(
-                self.model_class.status.notin_(
-                    [consts.DELETED, consts.PENDING_DELETE]),
-                self.model_class.cert_busy == false(),
-                self.model_class.cert_expiration < expired_date
-            ).first()
+            amp = session.query(self.model_class).with_for_update().filter_by(
+                cert_busy=False).filter(
+                self.model_class.cert_expiration < expired_date).first()
 
             if amp is None:
                 return None
@@ -1467,8 +1491,7 @@ class AmphoraHealthRepository(BaseRepository):
 
         amp = session.query(self.model_class).with_for_update().filter_by(
             busy=False).filter(
-            self.model_class.last_update < expired_time).order_by(
-            func.random()).first()
+            self.model_class.last_update < expired_time).first()
 
         if amp is None:
             return None
