@@ -28,8 +28,8 @@ class HAProxyCompatTestCase(base.TestCase):
             "global\n"
             "    daemon\n"
             "    user nobody\n"
-            "    log /dev/log local0\n"
-            "    log /dev/log local1 notice\n"
+            "    log /run/rsyslog/octavia/log local0\n"
+            "    log /run/rsyslog/octavia/log local1 notice\n"
             "    stats socket /var/lib/octavia/sample_loadbalancer_id_1.sock"
             " mode 0666 level user\n"
             "    maxconn {maxconn}\n\n"
@@ -41,7 +41,9 @@ class HAProxyCompatTestCase(base.TestCase):
             "    option splice-response\n"
             "    option http-keep-alive\n\n\n\n"
             "frontend sample_listener_id_1\n"
-            "    option httplog\n"
+            "    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
+            "%ci\\ %cp\\ %t\\ %{{+Q}}r\\ %ST\\ %B\\ %U\\ "
+            "%[ssl_c_verify]\\ %{{+Q}}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ %tsc\n"
             "    maxconn {maxconn}\n"
             "    bind 10.0.0.2:80\n"
             "    mode http\n"
