@@ -27,11 +27,10 @@ from octavia.amphorae.driver_exceptions import exceptions as driver_except
 from octavia.amphorae.drivers.haproxy import exceptions as exc
 from octavia.amphorae.drivers.haproxy import rest_api_driver as driver
 from octavia.common import constants
-from octavia.common import data_models
 from octavia.db import models
 from octavia.network import data_models as network_models
+from octavia.tests.common import sample_certs
 from octavia.tests.unit import base
-from octavia.tests.unit.common.sample_configs import sample_certs
 from octavia.tests.unit.common.sample_configs import sample_configs_combined
 
 API_VERSION = '1.0'
@@ -124,6 +123,16 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
         mock_amphora = mock.MagicMock()
         mock_amphora.id = 'mock_amphora_id'
         mock_amphora.api_version = API_VERSION
+        # mock_listener = mock.MagicMock()
+        # mock_listener.id = 'mock_listener_id'
+        # mock_listener.protocol = constants.PROTOCOL_HTTP
+        # mock_listener.connection_limit = constants.DEFAULT_CONNECTION_LIMIT
+        # mock_listener.tls_certificate_id = None
+        # mock_loadbalancer = mock.MagicMock()
+        # mock_loadbalancer.id = 'mock_lb_id'
+        # mock_loadbalancer.project_id = 'mock_lb_project'
+        # mock_loadbalancer.listeners = [mock_listener]
+        # mock_listener.load_balancer = mock_loadbalancer
         mock_secret.return_value = 'filename.pem'
         mock_load_cert.return_value = {
             'tls_cert': self.sl.default_tls_container, 'sni_certs': [],
@@ -159,27 +168,6 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
         self.driver.clients[API_VERSION].upload_config.assert_not_called()
         self.driver.clients[API_VERSION].reload_listener.assert_not_called()
 
-    @mock.patch('octavia.db.api.get_session')
-    @mock.patch('octavia.db.repositories.ListenerRepository.update')
-    @mock.patch('octavia.common.tls_utils.cert_parser.load_certificates_data')
-    def test_update_amphora_listeners_bad_cert(
-            self, mock_load_cert, mock_list_update, mock_get_session):
-        mock_amphora = mock.MagicMock()
-        mock_amphora.id = 'mock_amphora_id'
-        mock_amphora.api_version = API_VERSION
-
-        mock_get_session.return_value = 'fake_session'
-        mock_load_cert.side_effect = [Exception]
-        self.driver.update_amphora_listeners(self.lb,
-                                             mock_amphora, self.timeout_dict)
-        mock_list_update.assert_called_once_with(
-            'fake_session', self.lb.listeners[0].id,
-            provisioning_status=constants.ERROR,
-            operating_status=constants.ERROR)
-        self.driver.jinja_combo.build_config.assert_not_called()
-        (self.driver.clients[API_VERSION].delete_listener.
-         assert_called_once_with)(mock_amphora, self.lb.id)
-
     @mock.patch('octavia.amphorae.drivers.haproxy.rest_api_driver.'
                 'HaproxyAmphoraLoadBalancerDriver._process_secret')
     @mock.patch('octavia.common.tls_utils.cert_parser.load_certificates_data')
@@ -287,7 +275,7 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
             'sni_certs': sconts
         }
         self.driver.clients[API_VERSION].get_cert_md5sum.side_effect = [
-            exc.NotFound, 'Fake_MD5', 'aaaaa', 'aaaaa']
+            exc.NotFound, 'Fake_MD5', 'aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa']
         self.driver._process_tls_certificates(
             sample_listener, self.amp, sample_listener.load_balancer.id)
         gcm_calls = [
@@ -321,7 +309,7 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
         self.driver.clients[API_VERSION].upload_cert_pem.assert_has_calls(
             ucp_calls, any_order=True)
         self.assertEqual(
-            4, self.driver.clients[API_VERSION].upload_cert_pem.call_count)
+            3, self.driver.clients[API_VERSION].upload_cert_pem.call_count)
 
     @mock.patch('oslo_context.context.RequestContext')
     @mock.patch('octavia.amphorae.drivers.haproxy.rest_api_driver.'
@@ -402,24 +390,22 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
         conf.config(group="haproxy_amphora", base_cert_dir=fake_cert_dir)
         sample_listener = sample_configs_combined.sample_listener_tuple(
             pool_cert=True, pool_ca_cert=True, pool_crl=True)
-        pool_cert = data_models.TLSContainer(
-            id=uuidutils.generate_uuid(), certificate='pool cert')
-        pool_data = {'tls_cert': pool_cert, 'sni_certs': []}
-        mock_load_certs.return_value = pool_data
+        cert_data_mock = mock.MagicMock()
+        cert_data_mock.id = uuidutils.generate_uuid()
+        mock_load_certs.return_value = cert_data_mock
         fake_pem = b'fake pem'
         mock_build_pem.return_value = fake_pem
         ref_md5 = hashlib.md5(fake_pem).hexdigest()  # nosec
-        ref_name = '{id}.pem'.format(id=pool_cert.id)
-        ref_path = '{cert_dir}/{lb_id}/{name}'.format(
-            cert_dir=fake_cert_dir, lb_id=sample_listener.load_balancer.id,
-            name=ref_name)
+        ref_name = '{id}.pem'.format(id=cert_data_mock.id)
+        ref_path = '{cert_dir}/{list_id}/{name}'.format(
+            cert_dir=fake_cert_dir, list_id=sample_listener.id, name=ref_name)
         ref_ca_name = 'fake_ca.pem'
-        ref_ca_path = '{cert_dir}/{lb_id}/{name}'.format(
-            cert_dir=fake_cert_dir, lb_id=sample_listener.load_balancer.id,
+        ref_ca_path = '{cert_dir}/{list_id}/{name}'.format(
+            cert_dir=fake_cert_dir, list_id=sample_listener.id,
             name=ref_ca_name)
         ref_crl_name = 'fake_crl.pem'
-        ref_crl_path = '{cert_dir}/{lb_id}/{name}'.format(
-            cert_dir=fake_cert_dir, lb_id=sample_listener.load_balancer.id,
+        ref_crl_path = '{cert_dir}/{list_id}/{name}'.format(
+            cert_dir=fake_cert_dir, list_id=sample_listener.id,
             name=ref_crl_name)
         ref_result = {'client_cert': ref_path, 'ca_cert': ref_ca_path,
                       'crl': ref_crl_path}
@@ -437,7 +423,7 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
                       sample_listener.default_pool.crl_container_id,
                       self.amp, sample_listener.load_balancer.id)]
 
-        mock_build_pem.assert_called_once_with(pool_cert)
+        mock_build_pem.assert_called_once_with(cert_data_mock)
         mock_upload_cert.assert_called_once_with(
             self.amp, sample_listener.load_balancer.id, pem=fake_pem,
             md5=ref_md5, name=ref_name)
