@@ -16,15 +16,15 @@ import copy
 
 import mock
 
+from octavia_lib.api.drivers import data_models as driver_dm
 from octavia_lib.api.drivers import exceptions as lib_exceptions
 
-from octavia.api.drivers import data_models as driver_dm
 from octavia.api.drivers import exceptions as driver_exceptions
 from octavia.api.drivers import utils
 from octavia.common import constants
 from octavia.common import data_models
 from octavia.common import exceptions
-from octavia.tests.unit.api.drivers import sample_data_models
+from octavia.tests.common import sample_data_models
 from octavia.tests.unit import base
 
 
@@ -103,9 +103,13 @@ class TestUtils(base.TestCase):
         self.assertEqual({'admin_state_up': True},
                          result_dict)
 
+    @mock.patch('octavia.db.repositories.FlavorRepository.'
+                'get_flavor_metadata_dict')
+    @mock.patch('octavia.db.api.get_session')
     @mock.patch('octavia.api.drivers.utils._get_secret_data')
     @mock.patch('octavia.common.tls_utils.cert_parser.load_certificates_data')
-    def test_lb_dict_to_provider_dict(self, mock_load_cert, mock_secret):
+    def test_lb_dict_to_provider_dict(self, mock_load_cert, mock_secret,
+                                      mock_get_session, mock_get_flavor):
         cert1 = data_models.TLSContainer(certificate='cert 1')
         cert2 = data_models.TLSContainer(certificate='cert 2')
         cert3 = data_models.TLSContainer(certificate='cert 3')
@@ -120,6 +124,7 @@ class TestUtils(base.TestCase):
         mock_load_cert.side_effect = [pool_certs, listener_certs,
                                       listener_certs, listener_certs,
                                       listener_certs]
+        mock_get_flavor.return_value = {'shaved_ice': 'cherry'}
         test_lb_dict = {'name': 'lb1',
                         'project_id': self.sample_data.project_id,
                         'vip_subnet_id': self.sample_data.subnet_id,
@@ -133,20 +138,22 @@ class TestUtils(base.TestCase):
                         'description': '', 'admin_state_up': True,
                         'provisioning_status': constants.PENDING_CREATE,
                         'operating_status': constants.OFFLINE,
-                        'flavor_id': '',
+                        'flavor_id': 'flavor_id',
                         'provider': 'noop_driver'}
+        ref_listeners = copy.deepcopy(self.sample_data.provider_listeners)
         ref_prov_lb_dict = {
             'vip_address': self.sample_data.ip_address,
             'admin_state_up': True,
             'loadbalancer_id': self.sample_data.lb_id,
             'vip_subnet_id': self.sample_data.subnet_id,
-            'listeners': self.sample_data.provider_listeners,
+            'listeners': ref_listeners,
             'description': '',
             'project_id': self.sample_data.project_id,
             'vip_port_id': self.sample_data.port_id,
             'vip_qos_policy_id': self.sample_data.qos_policy_id,
             'vip_network_id': self.sample_data.network_id,
             'pools': self.sample_data.provider_pools,
+            'flavor': {'shaved_ice': 'cherry'},
             'name': 'lb1'}
         vip = data_models.Vip(ip_address=self.sample_data.ip_address,
                               network_id=self.sample_data.network_id,
@@ -160,16 +167,22 @@ class TestUtils(base.TestCase):
 
         self.assertEqual(ref_prov_lb_dict, provider_lb_dict)
 
-    def test_db_loadbalancer_to_provider_loadbalancer(self):
+    @mock.patch('octavia.db.repositories.FlavorRepository.'
+                'get_flavor_metadata_dict')
+    @mock.patch('octavia.db.api.get_session')
+    def test_db_loadbalancer_to_provider_loadbalancer(self, mock_get_session,
+                                                      mock_get_flavor):
+        mock_get_flavor.return_value = {'shaved_ice': 'cherry'}
         vip = data_models.Vip(ip_address=self.sample_data.ip_address,
                               network_id=self.sample_data.network_id,
                               port_id=self.sample_data.port_id,
                               subnet_id=self.sample_data.subnet_id)
-        test_db_lb = data_models.LoadBalancer(id=1, vip=vip)
+        test_db_lb = data_models.LoadBalancer(id=1, flavor_id='2', vip=vip)
         provider_lb = utils.db_loadbalancer_to_provider_loadbalancer(
             test_db_lb)
         ref_provider_lb = driver_dm.LoadBalancer(
             loadbalancer_id=1,
+            flavor={'shaved_ice': 'cherry'},
             vip_address=self.sample_data.ip_address,
             vip_network_id=self.sample_data.network_id,
             vip_port_id=self.sample_data.port_id,
@@ -199,24 +212,8 @@ class TestUtils(base.TestCase):
                                        'sni_certs': [cert2, cert3]}
         provider_listeners = utils.db_listeners_to_provider_listeners(
             self.sample_data.test_db_listeners)
-        self.assertEqual(self.sample_data.provider_listeners,
-                         provider_listeners)
-
-    @mock.patch('oslo_context.context.RequestContext', return_value=None)
-    def test_get_secret_data_errors(self, mock_context):
-        mock_cert_mngr = mock.MagicMock()
-
-        mock_cert_mngr.get_secret.side_effect = [Exception, Exception]
-
-        # Test for_delete == False path
-        self.assertRaises(exceptions.CertificateRetrievalException,
-                          utils._get_secret_data, mock_cert_mngr,
-                          'fake_project_id', 1)
-
-        # Test for_delete == True path
-        self.assertIsNone(
-            utils._get_secret_data(mock_cert_mngr, 'fake_project_id',
-                                   2, for_delete=True))
+        ref_listeners = copy.deepcopy(self.sample_data.provider_listeners)
+        self.assertEqual(ref_listeners, provider_listeners)
 
     @mock.patch('octavia.api.drivers.utils._get_secret_data')
     @mock.patch('octavia.common.tls_utils.cert_parser.load_certificates_data')
@@ -244,41 +241,6 @@ class TestUtils(base.TestCase):
             self.sample_data.test_listener1_dict)
         self.assertEqual(expect_prov, provider_listener)
 
-    @mock.patch('octavia.api.drivers.utils._get_secret_data')
-    @mock.patch('octavia.common.tls_utils.cert_parser.load_certificates_data')
-    def test_listener_dict_to_provider_dict_load_cert_error(
-            self, mock_load_cert, mock_secret):
-        mock_secret.side_effect = ['ca cert', 'X509 CRL FILE',
-                                   'X509 POOL CA CERT FILE',
-                                   'X509 POOL CRL FILE']
-        mock_load_cert.side_effect = [exceptions.OctaviaException,
-                                      Exception]
-
-        # Test load_cert exception for_delete == False path
-        self.assertRaises(exceptions.OctaviaException,
-                          utils.listener_dict_to_provider_dict,
-                          self.sample_data.test_listener1_dict)
-
-    @mock.patch('octavia.api.drivers.utils._get_secret_data')
-    @mock.patch('octavia.common.tls_utils.cert_parser.load_certificates_data')
-    def test_listener_dict_to_provider_dict_load_cert_error_for_delete(
-            self, mock_load_cert, mock_secret):
-        mock_secret.side_effect = ['ca cert', 'X509 CRL FILE',
-                                   'X509 POOL CA CERT FILE',
-                                   'X509 POOL CRL FILE']
-        mock_load_cert.side_effect = [Exception]
-
-        # Test load_cert exception for_delete == True path
-        expect_prov = copy.deepcopy(self.sample_data.provider_listener1_dict)
-        expect_pool_prov = copy.deepcopy(self.sample_data.provider_pool1_dict)
-        del expect_pool_prov['tls_container_data']
-        expect_prov['default_pool'] = expect_pool_prov
-        del expect_prov['default_tls_container_data']
-        del expect_prov['sni_container_data']
-        provider_listener = utils.listener_dict_to_provider_dict(
-            self.sample_data.test_listener1_dict, for_delete=True)
-        self.assertEqual(expect_prov, provider_listener)
-
     @mock.patch('octavia.api.drivers.utils._get_secret_data')
     @mock.patch('octavia.common.tls_utils.cert_parser.load_certificates_data')
     def test_listener_dict_to_provider_dict_SNI(self, mock_load_cert,
@@ -291,7 +253,7 @@ class TestUtils(base.TestCase):
                                        'sni_certs': [cert2, cert3]}
         # Test with bad SNI content
         test_listener = copy.deepcopy(self.sample_data.test_listener1_dict)
-        test_listener['sni_containers'] = [[]]
+        test_listener['sni_containers'] = [{}]
         self.assertRaises(exceptions.ValidationException,
                           utils.listener_dict_to_provider_dict,
                           test_listener)
@@ -353,37 +315,6 @@ class TestUtils(base.TestCase):
         provider_pool_dict.pop('crl_container_ref')
         self.assertEqual(expect_prov, provider_pool_dict)
 
-    @mock.patch('octavia.api.drivers.utils._get_secret_data')
-    @mock.patch('octavia.common.tls_utils.cert_parser.load_certificates_data')
-    def test_pool_dict_to_provider_dict_load_cert_error(
-            self, mock_load_cert, mock_secret):
-
-        mock_load_cert.side_effect = [exceptions.OctaviaException,
-                                      Exception]
-
-        # Test load_cert exception for_delete == False path
-        self.assertRaises(exceptions.OctaviaException,
-                          utils.pool_dict_to_provider_dict,
-                          self.sample_data.test_pool1_dict)
-
-    @mock.patch('octavia.api.drivers.utils._get_secret_data')
-    @mock.patch('octavia.common.tls_utils.cert_parser.load_certificates_data')
-    def test_pool_dict_to_provider_dict_load_cert_error_for_delete(
-            self, mock_load_cert, mock_secret):
-
-        mock_load_cert.side_effect = [Exception]
-
-        # Test load_cert exception for_delete == True path
-        mock_secret.side_effect = ['X509 POOL CA CERT FILE',
-                                   'X509 POOL CRL FILE']
-        expect_prov = copy.deepcopy(self.sample_data.provider_pool1_dict)
-        expect_prov.pop('crl_container_ref')
-        del expect_prov['tls_container_data']
-        provider_pool_dict = utils.pool_dict_to_provider_dict(
-            self.sample_data.test_pool1_dict, for_delete=True)
-        provider_pool_dict.pop('crl_container_ref')
-        self.assertEqual(expect_prov, provider_pool_dict)
-
     def test_db_HM_to_provider_HM(self):
         provider_hm = utils.db_HM_to_provider_HM(self.sample_data.db_hm1)
         self.assertEqual(self.sample_data.provider_hm1, provider_hm)
