@@ -16,16 +16,11 @@
 import copy
 import os
 
-from oslo_config import cfg
-from oslo_config import fixture as oslo_fixture
-
 from octavia.common import constants
 from octavia.common.jinja.haproxy.combined_listeners import jinja_cfg
 from octavia.tests.unit import base
 from octavia.tests.unit.common.sample_configs import sample_configs_combined
 
-CONF = cfg.CONF
-
 
 class TestHaproxyCfg(base.TestCase):
     def setUp(self):
@@ -39,25 +34,24 @@ class TestHaproxyCfg(base.TestCase):
         self.assertEqual('haproxy.cfg.j2', template.name)
 
     def test_render_template_tls(self):
-        conf = oslo_fixture.Config(cfg.CONF)
-        conf.config(group="haproxy_amphora", base_cert_dir='/fake_cert_dir')
-        FAKE_CRT_LIST_FILENAME = os.path.join(
-            CONF.haproxy_amphora.base_cert_dir,
-            'sample_loadbalancer_id_1/sample_listener_id_1.pem')
         fe = ("frontend sample_listener_id_1\n"
-              "    option httplog\n"
+              "    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
+              "%ci\\ %cp\\ %t\\ %{{+Q}}r\\ %ST\\ %B\\ %U\\ "
+              "%[ssl_c_verify]\\ %{{+Q}}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
+              "%tsc\n"
               "    maxconn {maxconn}\n"
               "    redirect scheme https if !{{ ssl_fc }}\n"
               "    bind 10.0.0.2:443 "
-              "ssl crt-list {crt_list} "
+              "ssl crt /var/lib/octavia/certs/"
+              "sample_loadbalancer_id_1/tls_container_id.pem "
+              "crt /var/lib/octavia/certs/sample_loadbalancer_id_1 "
               "ca-file /var/lib/octavia/certs/sample_loadbalancer_id_1/"
               "client_ca.pem verify required crl-file /var/lib/octavia/"
               "certs/sample_loadbalancer_id_1/SHA_ID.pem\n"
               "    mode http\n"
               "    default_backend sample_pool_id_1:sample_listener_id_1\n"
               "    timeout client 50000\n\n").format(
-            maxconn=constants.HAPROXY_MAX_MAXCONN,
-            crt_list=FAKE_CRT_LIST_FILENAME)
+            maxconn=constants.HAPROXY_MAX_MAXCONN)
         be = ("backend sample_pool_id_1:sample_listener_id_1\n"
               "    mode http\n"
               "    balance roundrobin\n"
@@ -80,36 +74,34 @@ class TestHaproxyCfg(base.TestCase):
                     sample_configs_combined.sample_tls_container_tuple(
                         id='tls_container_id',
                         certificate='imaCert1', private_key='imaPrivateKey1',
-                        primary_cn='FakeCN'),
-                    'cont_id_ca': 'client_ca.pem',
-                    'cont_id_crl': 'SHA_ID.pem'}
+                        primary_cn='FakeCN')}
         rendered_obj = self.jinja_cfg.render_loadbalancer_obj(
             sample_configs_combined.sample_amphora_tuple(),
             [sample_configs_combined.sample_listener_tuple(
                 proto='TERMINATED_HTTPS', tls=True, sni=True,
                 client_ca_cert=True, client_crl_cert=True)],
-            tls_tupe)
+            tls_tupe, client_ca_filename='client_ca.pem',
+            client_crl='SHA_ID.pem')
         self.assertEqual(
             sample_configs_combined.sample_base_expected_config(
                 frontend=fe, backend=be),
             rendered_obj)
 
     def test_render_template_tls_no_sni(self):
-        conf = oslo_fixture.Config(cfg.CONF)
-        conf.config(group="haproxy_amphora", base_cert_dir='/fake_cert_dir')
-        FAKE_CRT_LIST_FILENAME = os.path.join(
-            CONF.haproxy_amphora.base_cert_dir,
-            'sample_loadbalancer_id_1/sample_listener_id_1.pem')
         fe = ("frontend sample_listener_id_1\n"
-              "    option httplog\n"
+              "    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
+              "%ci\\ %cp\\ %t\\ %{{+Q}}r\\ %ST\\ %B\\ %U\\ "
+              "%[ssl_c_verify]\\ %{{+Q}}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
+              "%tsc\n"
               "    maxconn {maxconn}\n"
               "    redirect scheme https if !{{ ssl_fc }}\n"
-              "    bind 10.0.0.2:443 ssl crt-list {crt_list}\n"
+              "    bind 10.0.0.2:443 "
+              "ssl crt /var/lib/octavia/certs/"
+              "sample_loadbalancer_id_1/tls_container_id.pem\n"
               "    mode http\n"
               "    default_backend sample_pool_id_1:sample_listener_id_1\n"
               "    timeout client 50000\n\n").format(
-            maxconn=constants.HAPROXY_MAX_MAXCONN,
-            crt_list=FAKE_CRT_LIST_FILENAME)
+            maxconn=constants.HAPROXY_MAX_MAXCONN)
         be = ("backend sample_pool_id_1:sample_listener_id_1\n"
               "    mode http\n"
               "    balance roundrobin\n"
@@ -200,7 +192,10 @@ class TestHaproxyCfg(base.TestCase):
 
     def test_render_template_custom_timeouts(self):
         fe = ("frontend sample_listener_id_1\n"
-              "    option httplog\n"
+              "    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
+              "%ci\\ %cp\\ %t\\ %{{+Q}}r\\ %ST\\ %B\\ %U\\ "
+              "%[ssl_c_verify]\\ %{{+Q}}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
+              "%tsc\n"
               "    maxconn {maxconn}\n"
               "    bind 10.0.0.2:80\n"
               "    mode http\n"
@@ -236,7 +231,10 @@ class TestHaproxyCfg(base.TestCase):
 
     def test_render_template_null_timeouts(self):
         fe = ("frontend sample_listener_id_1\n"
-              "    option httplog\n"
+              "    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
+              "%ci\\ %cp\\ %t\\ %{{+Q}}r\\ %ST\\ %B\\ %U\\ "
+              "%[ssl_c_verify]\\ %{{+Q}}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
+              "%tsc\n"
               "    maxconn {maxconn}\n"
               "    bind 10.0.0.2:80\n"
               "    mode http\n"
@@ -301,7 +299,10 @@ class TestHaproxyCfg(base.TestCase):
 
     def test_render_template_https_real_monitor(self):
         fe = ("frontend sample_listener_id_1\n"
-              "    option tcplog\n"
+              "    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
+              "%ci\\ %cp\\ %t\\ -\\ -\\ %B\\ %U\\ "
+              "%[ssl_c_verify]\\ %{{+Q}}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
+              "%tsc\n"
               "    maxconn {maxconn}\n"
               "    bind 10.0.0.2:443\n"
               "    mode tcp\n"
@@ -334,7 +335,10 @@ class TestHaproxyCfg(base.TestCase):
 
     def test_render_template_https_hello_monitor(self):
         fe = ("frontend sample_listener_id_1\n"
-              "    option tcplog\n"
+              "    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
+              "%ci\\ %cp\\ %t\\ -\\ -\\ %B\\ %U\\ "
+              "%[ssl_c_verify]\\ %{{+Q}}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
+              "%tsc\n"
               "    maxconn {maxconn}\n"
               "    bind 10.0.0.2:443\n"
               "    mode tcp\n"
@@ -437,7 +441,10 @@ class TestHaproxyCfg(base.TestCase):
 
     def test_render_template_no_monitor_https(self):
         fe = ("frontend sample_listener_id_1\n"
-              "    option tcplog\n"
+              "    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
+              "%ci\\ %cp\\ %t\\ -\\ -\\ %B\\ %U\\ "
+              "%[ssl_c_verify]\\ %{{+Q}}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
+              "%tsc\n"
               "    maxconn {maxconn}\n"
               "    bind 10.0.0.2:443\n"
               "    mode tcp\n"
@@ -493,7 +500,10 @@ class TestHaproxyCfg(base.TestCase):
 
     def test_render_template_no_persistence_https(self):
         fe = ("frontend sample_listener_id_1\n"
-              "    option tcplog\n"
+              "    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
+              "%ci\\ %cp\\ %t\\ -\\ -\\ %B\\ %U\\ "
+              "%[ssl_c_verify]\\ %{{+Q}}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
+              "%tsc\n"
               "    maxconn {maxconn}\n"
               "    bind 10.0.0.2:443\n"
               "    mode tcp\n"
@@ -594,7 +604,10 @@ class TestHaproxyCfg(base.TestCase):
         sample_listener = sample_configs_combined.sample_listener_tuple(
             proto='HTTPS', monitor=False)
         fe = ("frontend {listener_id}\n"
-              "    option tcplog\n"
+              "    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
+              "%ci\\ %cp\\ %t\\ -\\ -\\ %B\\ %U\\ "
+              "%[ssl_c_verify]\\ %{{+Q}}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
+              "%tsc\n"
               "    maxconn {maxconn}\n"
               "    bind 10.0.0.2:443\n"
               "    mode tcp\n"
@@ -626,7 +639,10 @@ class TestHaproxyCfg(base.TestCase):
 
     def test_render_template_limited_connections(self):
         fe = ("frontend sample_listener_id_1\n"
-              "    option tcplog\n"
+              "    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
+              "%ci\\ %cp\\ %t\\ -\\ -\\ %B\\ %U\\ "
+              "%[ssl_c_verify]\\ %{+Q}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
+              "%tsc\n"
               "    maxconn 2014\n"
               "    bind 10.0.0.2:443\n"
               "    mode tcp\n"
@@ -654,7 +670,10 @@ class TestHaproxyCfg(base.TestCase):
 
     def test_render_template_l7policies(self):
         fe = ("frontend sample_listener_id_1\n"
-              "    option httplog\n"
+              "    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
+              "%ci\\ %cp\\ %t\\ %{{+Q}}r\\ %ST\\ %B\\ %U\\ "
+              "%[ssl_c_verify]\\ %{{+Q}}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
+              "%tsc\n"
               "    maxconn {maxconn}\n"
               "    bind 10.0.0.2:80\n"
               "    mode http\n"
@@ -825,7 +844,7 @@ class TestHaproxyCfg(base.TestCase):
             sample_configs_combined.sample_amphora_tuple(),
             [sample_configs_combined.sample_listener_tuple(
                 pool_cert=True, tls_enabled=True)],
-            tls_certs={
+            pool_tls_certs={
                 'sample_pool_id_1':
                     {'client_cert': cert_file_path,
                      'ca_cert': None, 'crl': None}})
@@ -865,7 +884,7 @@ class TestHaproxyCfg(base.TestCase):
             [sample_configs_combined.sample_listener_tuple(
                 pool_cert=True, pool_ca_cert=True, pool_crl=True,
                 tls_enabled=True)],
-            tls_certs={
+            pool_tls_certs={
                 'sample_pool_id_1':
                     {'client_cert': pool_client_cert,
                      'ca_cert': pool_ca_cert,
@@ -1105,7 +1124,10 @@ class TestHaproxyCfg(base.TestCase):
             base_amp_path='/var/lib/octavia',
             base_crt_dir='/var/lib/octavia/certs')
         fe = ("frontend sample_listener_id_1\n"
-              "    option httplog\n"
+              "    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
+              "%ci\\ %cp\\ %t\\ %{+Q}r\\ %ST\\ %B\\ %U\\ "
+              "%[ssl_c_verify]\\ %{+Q}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
+              "%tsc\n"
               "    maxconn 1000000\n"
               "    redirect scheme https if !{ ssl_fc }\n"
               "    bind 10.0.0.2:443\n"
