@@ -18,7 +18,7 @@ import collections
 from oslo_config import cfg
 
 from octavia.common import constants
-from octavia.tests.unit.common.sample_configs import sample_certs
+from octavia.tests.common import sample_certs
 
 CONF = cfg.CONF
 
@@ -296,6 +296,9 @@ RET_LISTENER = {
     'protocol_mode': 'http',
     'default_pool': RET_POOL_1,
     'connection_limit': constants.HAPROXY_MAX_MAXCONN,
+    'user_log_format': '12345\\ sample_loadbalancer_id_1\\ %f\\ %ci\\ %cp\\ '
+                       '%t\\ %{+Q}r\\ %ST\\ %B\\ %U\\ %[ssl_c_verify]\\ '
+                       '%{+Q}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ %tsc',
     'pools': [RET_POOL_1],
     'l7policies': [],
     'enabled': True,
@@ -313,6 +316,9 @@ RET_LISTENER_L7 = {
     'protocol_mode': 'http',
     'default_pool': RET_POOL_1,
     'connection_limit': constants.HAPROXY_MAX_MAXCONN,
+    'user_log_format': '12345\\ sample_loadbalancer_id_1\\ %f\\ %ci\\ %cp\\ '
+                       '%t\\ %{+Q}r\\ %ST\\ %B\\ %U\\ %[ssl_c_verify]\\ '
+                       '%{+Q}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ %tsc',
     'l7policies': [RET_L7POLICY_1, RET_L7POLICY_2, RET_L7POLICY_3,
                    RET_L7POLICY_4, RET_L7POLICY_5, RET_L7POLICY_6,
                    RET_L7POLICY_7],
@@ -446,7 +452,7 @@ UDP_MEMBER_1 = {
     'protocol_port': 82,
     'weight': 13,
     'monitor_address': None,
-    'monitor_port': None
+    'monitor_port': None,
 }
 
 UDP_MEMBER_2 = {
@@ -756,16 +762,14 @@ def sample_pool_tuple(listener_id=None, proto=None, monitor=True,
                       backup_member=False, disabled_member=False,
                       has_http_reuse=True, pool_cert=False, pool_ca_cert=False,
                       pool_crl=False, tls_enabled=False,
-                      hm_host_http_check=False,
-                      provisioning_status=constants.ACTIVE):
+                      hm_host_http_check=False):
     proto = 'HTTP' if proto is None else proto
     monitor_proto = proto if monitor_proto is None else monitor_proto
     in_pool = collections.namedtuple(
         'pool', 'id, protocol, lb_algorithm, members, health_monitor, '
                 'session_persistence, enabled, operating_status, '
                 'tls_certificate_id, ca_tls_certificate_id, '
-                'crl_container_id, tls_enabled, '
-                'provisioning_status, ' + constants.HTTP_REUSE)
+                'crl_container_id, tls_enabled, ' + constants.HTTP_REUSE)
     if (proto == constants.PROTOCOL_UDP and
             persistence_type == constants.SESSION_PERSISTENCE_SOURCE_IP):
         kwargs = {'persistence_type': persistence_type,
@@ -807,7 +811,7 @@ def sample_pool_tuple(listener_id=None, proto=None, monitor=True,
         tls_certificate_id='pool_cont_1' if pool_cert else None,
         ca_tls_certificate_id='pool_ca_1' if pool_ca_cert else None,
         crl_container_id='pool_crl' if pool_crl else None,
-        tls_enabled=tls_enabled, provisioning_status=constants.ACTIVE)
+        tls_enabled=tls_enabled)
 
 
 def sample_member_tuple(id, ip, enabled=True, operating_status='ACTIVE',
@@ -1035,7 +1039,10 @@ def sample_base_expected_config(frontend=None, backend=None,
                                 peers=None, global_opts=None, defaults=None):
     if frontend is None:
         frontend = ("frontend sample_listener_id_1\n"
-                    "    option httplog\n"
+                    "    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
+                    "%ci\\ %cp\\ %t\\ %{{+Q}}r\\ %ST\\ %B\\ %U\\ "
+                    "%[ssl_c_verify]\\ %{{+Q}}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
+                    "%tsc\n"
                     "    maxconn {maxconn}\n"
                     "    bind 10.0.0.2:80\n"
                     "    mode http\n"
@@ -1078,8 +1085,8 @@ def sample_base_expected_config(frontend=None, backend=None,
             "global\n"
             "    daemon\n"
             "    user nobody\n"
-            "    log /dev/log local0\n"
-            "    log /dev/log local1 notice\n"
+            "    log /run/rsyslog/octavia/log local0\n"
+            "    log /run/rsyslog/octavia/log local1 notice\n"
             "    stats socket /var/lib/octavia/sample_loadbalancer_id_1.sock"
             " mode 0666 level user\n" +
             global_opts + defaults + peers + frontend + backend)
