@@ -18,7 +18,7 @@ import collections
 from oslo_config import cfg
 
 from octavia.common import constants
-from octavia.tests.unit.common.sample_configs import sample_certs
+from octavia.tests.common import sample_certs
 
 CONF = cfg.CONF
 
@@ -296,6 +296,9 @@ RET_LISTENER = {
     'amphorae': [sample_amphora_tuple()],
     'peer_port': 1024,
     'topology': 'SINGLE',
+    'user_log_format': '12345\\ sample_loadbalancer_id_1\\ %f\\ %ci\\ %cp\\ '
+                       '%t\\ %{+Q}r\\ %ST\\ %B\\ %U\\ %[ssl_c_verify]\\ '
+                       '%{+Q}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ %tsc',
     'pools': [RET_POOL_1],
     'l7policies': [],
     'enabled': True,
@@ -316,6 +319,9 @@ RET_LISTENER_L7 = {
     'amphorae': [sample_amphora_tuple()],
     'peer_port': 1024,
     'topology': 'SINGLE',
+    'user_log_format': '12345\\ sample_loadbalancer_id_1\\ %f\\ %ci\\ %cp\\ '
+                       '%t\\ %{+Q}r\\ %ST\\ %B\\ %U\\ %[ssl_c_verify]\\ '
+                       '%{+Q}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ %tsc',
     'pools': [RET_POOL_1, RET_POOL_2],
     'l7policies': [RET_L7POLICY_1, RET_L7POLICY_2, RET_L7POLICY_3,
                    RET_L7POLICY_4, RET_L7POLICY_5, RET_L7POLICY_6,
@@ -1028,7 +1034,7 @@ def sample_l7rule_tuple(id,
         type = constants.L7RULE_TYPE_SSL_DN_FIELD
         compare_type = constants.L7RULE_COMPARE_TYPE_REGEX
         key = 'STREET'
-        value = '^STREET.*NO\.$'
+        value = r'^STREET.*NO\.$'
         invert = True
         enabled = True
     if sample_rule == 10:
@@ -1052,7 +1058,10 @@ def sample_base_expected_config(frontend=None, backend=None,
                                 peers=None, global_opts=None, defaults=None):
     if frontend is None:
         frontend = ("frontend sample_listener_id_1\n"
-                    "    option httplog\n"
+                    "    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
+                    "%ci\\ %cp\\ %t\\ %{{+Q}}r\\ %ST\\ %B\\ %U\\ "
+                    "%[ssl_c_verify]\\ %{{+Q}}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ "
+                    "%tsc\n"
                     "    maxconn {maxconn}\n"
                     "    bind 10.0.0.2:80\n"
                     "    mode http\n"
@@ -1094,8 +1103,8 @@ def sample_base_expected_config(frontend=None, backend=None,
             "global\n"
             "    daemon\n"
             "    user nobody\n"
-            "    log /dev/log local0\n"
-            "    log /dev/log local1 notice\n"
+            "    log /run/rsyslog/octavia/log local0\n"
+            "    log /run/rsyslog/octavia/log local1 notice\n"
             "    stats socket /var/lib/octavia/sample_listener_id_1.sock"
             " mode 0666 level user\n" +
             global_opts + defaults + peers + frontend + backend)
