@@ -75,9 +75,9 @@ class TestBaseNeutronNetworkDriver(base.TestCase):
         self.driver._add_allowed_address_pair_to_port(
             t_constants.MOCK_PORT_ID, t_constants.MOCK_IP_ADDRESS)
         expected_aap_dict = {
-                'port': {
-                    'allowed_address_pairs': [
-                        {'ip_address': t_constants.MOCK_IP_ADDRESS}]}}
+            'port': {
+                'allowed_address_pairs': [
+                    {'ip_address': t_constants.MOCK_IP_ADDRESS}]}}
         self.driver.neutron_client.update_port.assert_has_calls([
             mock.call(t_constants.MOCK_PORT_ID, expected_aap_dict)])
 
@@ -137,7 +137,8 @@ class TestBaseNeutronNetworkDriver(base.TestCase):
             protocol=2,
             port_min=3,
             port_max=4,
-            ethertype=5)
+            ethertype=5,
+            cidr="10.0.0.0/24")
         expected_sec_grp_rule_dict = {
             'security_group_rule': {
                 'security_group_id': t_constants.MOCK_SECURITY_GROUP_ID,
@@ -145,7 +146,8 @@ class TestBaseNeutronNetworkDriver(base.TestCase):
                 'protocol': 2,
                 'port_range_min': 3,
                 'port_range_max': 4,
-                'ethertype': 5}}
+                'ethertype': 5,
+                'remote_ip_prefix': '10.0.0.0/24'}}
         self.driver.neutron_client.create_security_group_rule.assert_has_calls(
             [mock.call(expected_sec_grp_rule_dict)])
 
@@ -479,3 +481,18 @@ class TestBaseNeutronNetworkDriver(base.TestCase):
                           self.driver.apply_qos_on_port,
                           t_constants.MOCK_PORT_ID,
                           t_constants.MOCK_NEUTRON_QOS_POLICY_ID)
+
+    def test_get_network_ip_availability(self):
+        show_network_ip_availability = (
+            self.driver.neutron_client.show_network_ip_availability)
+        show_network_ip_availability.return_value = (
+            {'network_ip_availability': {
+             'network_id': t_constants.MOCK_NETWORK_ID,
+             'subnet_ip_availability': t_constants.MOCK_SUBNET_IP_AVAILABILITY
+             }})
+        ip_avail = self.driver.get_network_ip_availability(
+            network_models.Network(t_constants.MOCK_NETWORK_ID))
+        self.assertIsInstance(ip_avail, network_models.Network_IP_Availability)
+        self.assertEqual(t_constants.MOCK_NETWORK_ID, ip_avail.network_id)
+        self.assertEqual(t_constants.MOCK_SUBNET_IP_AVAILABILITY,
+                         ip_avail.subnet_ip_availability)
